******************************************************
** PROJECT     : CCD BOARD TEST SEQUENCER CODE VERSION 0.0
** TITLE       : CCD BOARD EXERCISE CODE FOR REV 'A' HARDWARE
**             : 
**
** HISTORY     : 31/AUG/2005: PCM VER 0.0 USING NEW CCD MICRO SEQUENCER
**
** DESCRIPTION : CODE TO RUN THE CCD TEST STAND
**             : COMPILE WITH ASM4 OR LATER.
** SIGNAL
** ASSIGNMENTS : NONE USED SINCE WE RUN THIS CODE WITH ONLY THE CCD BOARD INSTALLED
**     
**********************
** TIMING CONSTANTS **
**********************
DEF #PAN_DLY        200                 * 500 ms DELAY BEFORE SENDING DATA TO PAN
DEF #CDSCMD0    x0010B00            * Run 500 KPix/sec normal acquisition
DEF #CDSCMD1    x0010B10            * Run 500 KPix/sec acquisition with DC Clamp on
DEF #CDSCMD2    x0010B20            * Run 500 KPix/sec acquisition with DC Clamp + reset on
DEF #CDSCMD3    x0010B30            * Run 800 KPix/sec acquisition
************************************************************************************
** COPY OF CCDACQ BOARD MICRO SEQUENCER CODE BLOCK
** THIS MUST BE INSERTED BY HAND AT THE END OF THE CCDBOARDTESTS_SEQUENCER.UCD FILE
************************************************************************************
*  #
*  addr=ccdSeqPatMem        # pattern memory address of CCD board
*  # Start Addr = 00 Runlength = 0B - 500 KPix/sec readout with DC clamp + reset on
*  0x047E 0x043E 0x043E 0x183E 0x043E 0x043E 0x043E 0x183E
*  0x043E 0x023F 0x013E 0x0000 0x0000 0x0000 0x0000 0x0000
*  #
*  # Start Addr = 10 Runlength = 0B - 500 KPix/sec readout with DC clamp on
*  0x0476 0x0432 0x0412 0x181A 0x0412 0x0416 0x0414 0x181C
*  0x0414 0x0215 0x0136 0x0000 0x0000 0x0000 0x0000 0x0000
*  #
*  # Start Addr = 20 Runlength = 0B - 500 KPix/sec readout
*  0x0476 0x0422 0x0402 0x180A 0x0402 0x0406 0x0404 0x180C
*  0x0404 0x0205 0x0136 0x0000 0x0000 0x0000 0x0000 0x0000
*  #
*  # Start Addr = 30 Runlength = 0B - Normal high speed acquisition = 800KPix/sec
*  0x0276 0x0222 0x0202 0x100a 0x0202 0x0206 0x0204 0x100c
*  0x0204 0x0105 0x0136 0x0000 0x0000 0x0000 0x0000 0x0000 
*  #
*  
***********************************************************************************
*
*******************************
** LOOP REGISTER DEFINITIONS **
*******************************
DEF #ROWS         0                 * NUMBER OF ROWS TO READOUT - NOMINALLY SET TO 1
DEF #COLS         1                 * NUMBER OF COLUMNS TO READOUT  - NOMINALLY SET TO 2048
DEF #SPAN         9                 * NUMBER OF TIMES TO SET DACS - NOMINALLY SET TO 32
DEF #DACS         7                 * NUMBER OF DACS TO SET THROUGH EACH SPAN STEP - NOMINALLY SET TO 8
DEF #CDS_DLY      10                * Delay time between CDS sequence triggers  - NOMINALLY SET TO 5 us
DEF #DOP_DLY      5                 * DELAY BETWEEN FIRING CDS AND SETTING THE DOP NEG STEP 
**
**************************************************************
** JUMP FLAG DEFINITIONS - BIT POSITION IN COMMAND REGISTER **
**************************************************************
DEF #SYNC        1                  * Jump on sync bit high
DEF #ITC         2                  * Jump on Integration time expired
DEF #START       3                  * Jump on start exposure flag set
DEF #VCTR_1      4                  * STRVCTR =  1: READOUT CLAMPED AND RESET MODE
DEF #VCTR_2      5                  * STRVCTR =  2: READOUT CLAMPED MODE
DEF #VCTR_3      6                  * STRVCTR =  4: READOUT NORMALLY
DEF #VCTR_4      7                  * STRVCTR =  8:
DEF #VCTR_5      8                  * STRVCTR = 16: 
DEF #VCTR_6      9                  * STRVCTR = 32: 
DEF #VCTR_7     10                  * STRVCTR = 64:
DEF #VCTR_8     11                  * STRVCTR =128:
DEF #CONT_RUN   12                  * USER BIT 1: LOOP INDEFINATELY ON TESTS
DEF #USR_2      13                  * Jump on user mode bit value 2
DEF #USR_3      14                  * Jump on user mode bit value 4
DEF #USR_4      15                  * Jump on user mode bit value 8
**
****************************
** EFR REGISTER CONSTANTS **
****************************
DEF #KILL_EXPFLG    x00000001       * Cancel start exposure flag (bit 3 of Command Register) using the EFR register
DEF #STRT_INTCNTR   x00000002       * Start the integration time counter using the EFR register
DEF #STOP_INTCNTR   x00000004       * Stop the integration time counter using the EFR register
DEF #LSR_AUTO_KILL  x00000100       * Enables automatic board select cancel after an LSR instruction
DEF #LSR_MAN_RESET  x00000200       * Disables automatic board select cancel. LSR will remain active until an LSR #DSLCT is issued
DEF #SET_SYNC_LOW   x00004000       * If enabled as master DHE, set sync bit low after sync delay
DEF #SET_SYNC_HIGH  x00008000       * If enabled as master DHE, set sync signal high immediately
DEF #KILLANDSYNC    x00004001       * Set sync low and kill start exposure flag
**
*****************************
** MODE REGISTER CONSTANTS **
*****************************
DEF #RESET       0                  * Mode register constant for board reset operation
DEF #READ        1                  * Mode register constant for read operation
DEF #WRITE16     2                  * Mode register constant for 16 bit write operation
DEF #WRITE32     3                  * Mode register constant for 32 bit write operation
**
**********************************
** LSR BOARD SELECT ASSIGNMENTS **
**********************************
DEF #DSLCT       0
DEF #MCB         1
DEF #CCDACQ     32                  * ASSIGNED TO SLOT 6
**
** CCDACQ BOARD ADDRESS POINTERS
DEF #CDSREG      x0000
DEF #DOPREG      x0001
DEF #BRSTCMD     x0004
DEF #SEQCMD      x0005
**
********************************
** DOP PORT VALUES FOR EDGE TEST
********************************
DEF #DOPHI     xFFFFFFFF
DEF #DOPLO     x00000000
**
**********************
** DAC OFFSET WORDS **
**********************
** ADDRESS BASES
DEF #DAC0_ADDR x02100000
DEF #DAC1_ADDR x02110000
DEF #DAC2_ADDR x02120000
DEF #DAC3_ADDR x02130000
DEF #DAC4_ADDR x02140000
DEF #DAC5_ADDR x02150000
DEF #DAC6_ADDR x02160000
DEF #DAC7_ADDR x02170000
**
** DATA VALUES
DEF #OFFSET00 x0000
DEF #OFFSET01 x0040
DEF #OFFSET02 x0080
DEF #OFFSET03 x00C0
DEF #OFFSET04 x0100
DEF #OFFSET05 x0140
DEF #OFFSET06 x0180
DEF #OFFSET07 x01C0
DEF #OFFSET08 x0200
DEF #OFFSET09 x0240
DEF #OFFSET0A x0280
DEF #OFFSET0B x02C0
DEF #OFFSET0C x0300
DEF #OFFSET0D x0340
DEF #OFFSET0E x0380
DEF #OFFSET0F x03C0

DEF #OFFSET10 x0400
DEF #OFFSET11 x0440
DEF #OFFSET12 x0480
DEF #OFFSET13 x04C0
DEF #OFFSET14 x0500
DEF #OFFSET15 x0540
DEF #OFFSET16 x0580
DEF #OFFSET17 x05C0
DEF #OFFSET18 x0600
DEF #OFFSET19 x0640
DEF #OFFSET1A x0680
DEF #OFFSET1B x06C0
DEF #OFFSET1C x0700
DEF #OFFSET1D x0740
DEF #OFFSET1E x0780
DEF #OFFSET1F x07C0

DEF #OFFSET20 x0800
DEF #OFFSET21 x0840
DEF #OFFSET22 x0880
DEF #OFFSET23 x08C0
DEF #OFFSET24 x0900
DEF #OFFSET25 x0940
DEF #OFFSET26 x0980
DEF #OFFSET27 x09C0
DEF #OFFSET28 x0A00
DEF #OFFSET29 x0A40
DEF #OFFSET2A x0A80
DEF #OFFSET2B x0AC0
DEF #OFFSET2C x0B00
DEF #OFFSET2D x0B40
DEF #OFFSET2E x0B80
DEF #OFFSET2F x0BC0

DEF #OFFSET30 x0C00
DEF #OFFSET31 x0C40
DEF #OFFSET32 x0C80
DEF #OFFSET33 x0CC0
DEF #OFFSET34 x0D00
DEF #OFFSET35 x0D40
DEF #OFFSET36 x0D80
DEF #OFFSET37 x0DC0
DEF #OFFSET38 x0E00
DEF #OFFSET39 x0E40
DEF #OFFSET3A x0E80
DEF #OFFSET3B x0EC0
DEF #OFFSET3C x0F00
DEF #OFFSET3D x0F40
DEF #OFFSET3E x0F80
DEF #OFFSET3F x0FC0

DEF #VAL000 #DAC0_ADDR OR #OFFSET00
DEF #VAL001 #DAC1_ADDR OR #OFFSET00
DEF #VAL002 #DAC2_ADDR OR #OFFSET00
DEF #VAL003 #DAC3_ADDR OR #OFFSET00
DEF #VAL004 #DAC4_ADDR OR #OFFSET00
DEF #VAL005 #DAC5_ADDR OR #OFFSET00
DEF #VAL006 #DAC6_ADDR OR #OFFSET00
DEF #VAL007 #DAC7_ADDR OR #OFFSET00

DEF #VAL010 #DAC0_ADDR OR #OFFSET01
DEF #VAL011 #DAC1_ADDR OR #OFFSET01
DEF #VAL012 #DAC2_ADDR OR #OFFSET01
DEF #VAL013 #DAC3_ADDR OR #OFFSET01
DEF #VAL014 #DAC4_ADDR OR #OFFSET01
DEF #VAL015 #DAC5_ADDR OR #OFFSET01
DEF #VAL016 #DAC6_ADDR OR #OFFSET01
DEF #VAL017 #DAC7_ADDR OR #OFFSET01

DEF #VAL020 #DAC0_ADDR OR #OFFSET02
DEF #VAL021 #DAC1_ADDR OR #OFFSET02
DEF #VAL022 #DAC2_ADDR OR #OFFSET02
DEF #VAL023 #DAC3_ADDR OR #OFFSET02
DEF #VAL024 #DAC4_ADDR OR #OFFSET02
DEF #VAL025 #DAC5_ADDR OR #OFFSET02
DEF #VAL026 #DAC6_ADDR OR #OFFSET02
DEF #VAL027 #DAC7_ADDR OR #OFFSET02

DEF #VAL030 #DAC0_ADDR OR #OFFSET03
DEF #VAL031 #DAC1_ADDR OR #OFFSET03
DEF #VAL032 #DAC2_ADDR OR #OFFSET03
DEF #VAL033 #DAC3_ADDR OR #OFFSET03
DEF #VAL034 #DAC4_ADDR OR #OFFSET03
DEF #VAL035 #DAC5_ADDR OR #OFFSET03
DEF #VAL036 #DAC6_ADDR OR #OFFSET03
DEF #VAL037 #DAC7_ADDR OR #OFFSET03

DEF #VAL040 #DAC0_ADDR OR #OFFSET04
DEF #VAL041 #DAC1_ADDR OR #OFFSET04
DEF #VAL042 #DAC2_ADDR OR #OFFSET04
DEF #VAL043 #DAC3_ADDR OR #OFFSET04
DEF #VAL044 #DAC4_ADDR OR #OFFSET04
DEF #VAL045 #DAC5_ADDR OR #OFFSET04
DEF #VAL046 #DAC6_ADDR OR #OFFSET04
DEF #VAL047 #DAC7_ADDR OR #OFFSET04

DEF #VAL050 #DAC0_ADDR OR #OFFSET05
DEF #VAL051 #DAC1_ADDR OR #OFFSET05
DEF #VAL052 #DAC2_ADDR OR #OFFSET05
DEF #VAL053 #DAC3_ADDR OR #OFFSET05
DEF #VAL054 #DAC4_ADDR OR #OFFSET05
DEF #VAL055 #DAC5_ADDR OR #OFFSET05
DEF #VAL056 #DAC6_ADDR OR #OFFSET05
DEF #VAL057 #DAC7_ADDR OR #OFFSET05

DEF #VAL060 #DAC0_ADDR OR #OFFSET06
DEF #VAL061 #DAC1_ADDR OR #OFFSET06
DEF #VAL062 #DAC2_ADDR OR #OFFSET06
DEF #VAL063 #DAC3_ADDR OR #OFFSET06
DEF #VAL064 #DAC4_ADDR OR #OFFSET06
DEF #VAL065 #DAC5_ADDR OR #OFFSET06
DEF #VAL066 #DAC6_ADDR OR #OFFSET06
DEF #VAL067 #DAC7_ADDR OR #OFFSET06

DEF #VAL070 #DAC0_ADDR OR #OFFSET07
DEF #VAL071 #DAC1_ADDR OR #OFFSET07
DEF #VAL072 #DAC2_ADDR OR #OFFSET07
DEF #VAL073 #DAC3_ADDR OR #OFFSET07
DEF #VAL074 #DAC4_ADDR OR #OFFSET07
DEF #VAL075 #DAC5_ADDR OR #OFFSET07
DEF #VAL076 #DAC6_ADDR OR #OFFSET07
DEF #VAL077 #DAC7_ADDR OR #OFFSET07

DEF #VAL080 #DAC0_ADDR OR #OFFSET08
DEF #VAL081 #DAC1_ADDR OR #OFFSET08
DEF #VAL082 #DAC2_ADDR OR #OFFSET08
DEF #VAL083 #DAC3_ADDR OR #OFFSET08
DEF #VAL084 #DAC4_ADDR OR #OFFSET08
DEF #VAL085 #DAC5_ADDR OR #OFFSET08
DEF #VAL086 #DAC6_ADDR OR #OFFSET08
DEF #VAL087 #DAC7_ADDR OR #OFFSET08

DEF #VAL090 #DAC0_ADDR OR #OFFSET09
DEF #VAL091 #DAC1_ADDR OR #OFFSET09
DEF #VAL092 #DAC2_ADDR OR #OFFSET09
DEF #VAL093 #DAC3_ADDR OR #OFFSET09
DEF #VAL094 #DAC4_ADDR OR #OFFSET09
DEF #VAL095 #DAC5_ADDR OR #OFFSET09
DEF #VAL096 #DAC6_ADDR OR #OFFSET09
DEF #VAL097 #DAC7_ADDR OR #OFFSET09

DEF #VAL0A0 #DAC0_ADDR OR #OFFSET0A
DEF #VAL0A1 #DAC1_ADDR OR #OFFSET0A
DEF #VAL0A2 #DAC2_ADDR OR #OFFSET0A
DEF #VAL0A3 #DAC3_ADDR OR #OFFSET0A
DEF #VAL0A4 #DAC4_ADDR OR #OFFSET0A
DEF #VAL0A5 #DAC5_ADDR OR #OFFSET0A
DEF #VAL0A6 #DAC6_ADDR OR #OFFSET0A
DEF #VAL0A7 #DAC7_ADDR OR #OFFSET0A

DEF #VAL0B0 #DAC0_ADDR OR #OFFSET0B
DEF #VAL0B1 #DAC1_ADDR OR #OFFSET0B
DEF #VAL0B2 #DAC2_ADDR OR #OFFSET0B
DEF #VAL0B3 #DAC3_ADDR OR #OFFSET0B
DEF #VAL0B4 #DAC4_ADDR OR #OFFSET0B
DEF #VAL0B5 #DAC5_ADDR OR #OFFSET0B
DEF #VAL0B6 #DAC6_ADDR OR #OFFSET0B
DEF #VAL0B7 #DAC7_ADDR OR #OFFSET0B

DEF #VAL0C0 #DAC0_ADDR OR #OFFSET0C
DEF #VAL0C1 #DAC1_ADDR OR #OFFSET0C
DEF #VAL0C2 #DAC2_ADDR OR #OFFSET0C
DEF #VAL0C3 #DAC3_ADDR OR #OFFSET0C
DEF #VAL0C4 #DAC4_ADDR OR #OFFSET0C
DEF #VAL0C5 #DAC5_ADDR OR #OFFSET0C
DEF #VAL0C6 #DAC6_ADDR OR #OFFSET0C
DEF #VAL0C7 #DAC7_ADDR OR #OFFSET0C

DEF #VAL0D0 #DAC0_ADDR OR #OFFSET0D
DEF #VAL0D1 #DAC1_ADDR OR #OFFSET0D
DEF #VAL0D2 #DAC2_ADDR OR #OFFSET0D
DEF #VAL0D3 #DAC3_ADDR OR #OFFSET0D
DEF #VAL0D4 #DAC4_ADDR OR #OFFSET0D
DEF #VAL0D5 #DAC5_ADDR OR #OFFSET0D
DEF #VAL0D6 #DAC6_ADDR OR #OFFSET0D
DEF #VAL0D7 #DAC7_ADDR OR #OFFSET0D

DEF #VAL0E0 #DAC0_ADDR OR #OFFSET0E
DEF #VAL0E1 #DAC1_ADDR OR #OFFSET0E
DEF #VAL0E2 #DAC2_ADDR OR #OFFSET0E
DEF #VAL0E3 #DAC3_ADDR OR #OFFSET0E
DEF #VAL0E4 #DAC4_ADDR OR #OFFSET0E
DEF #VAL0E5 #DAC5_ADDR OR #OFFSET0E
DEF #VAL0E6 #DAC6_ADDR OR #OFFSET0E
DEF #VAL0E7 #DAC7_ADDR OR #OFFSET0E

DEF #VAL0F0 #DAC0_ADDR OR #OFFSET0F
DEF #VAL0F1 #DAC1_ADDR OR #OFFSET0F
DEF #VAL0F2 #DAC2_ADDR OR #OFFSET0F
DEF #VAL0F3 #DAC3_ADDR OR #OFFSET0F
DEF #VAL0F4 #DAC4_ADDR OR #OFFSET0F
DEF #VAL0F5 #DAC5_ADDR OR #OFFSET0F
DEF #VAL0F6 #DAC6_ADDR OR #OFFSET0F
DEF #VAL0F7 #DAC7_ADDR OR #OFFSET0F

DEF #VAL100 #DAC0_ADDR OR #OFFSET10
DEF #VAL101 #DAC1_ADDR OR #OFFSET10
DEF #VAL102 #DAC2_ADDR OR #OFFSET10
DEF #VAL103 #DAC3_ADDR OR #OFFSET10
DEF #VAL104 #DAC4_ADDR OR #OFFSET10
DEF #VAL105 #DAC5_ADDR OR #OFFSET10
DEF #VAL106 #DAC6_ADDR OR #OFFSET10
DEF #VAL107 #DAC7_ADDR OR #OFFSET10

DEF #VAL110 #DAC0_ADDR OR #OFFSET11
DEF #VAL111 #DAC1_ADDR OR #OFFSET11
DEF #VAL112 #DAC2_ADDR OR #OFFSET11
DEF #VAL113 #DAC3_ADDR OR #OFFSET11
DEF #VAL114 #DAC4_ADDR OR #OFFSET11
DEF #VAL115 #DAC5_ADDR OR #OFFSET11
DEF #VAL116 #DAC6_ADDR OR #OFFSET11
DEF #VAL117 #DAC7_ADDR OR #OFFSET11

DEF #VAL120 #DAC0_ADDR OR #OFFSET12
DEF #VAL121 #DAC1_ADDR OR #OFFSET12
DEF #VAL122 #DAC2_ADDR OR #OFFSET12
DEF #VAL123 #DAC3_ADDR OR #OFFSET12
DEF #VAL124 #DAC4_ADDR OR #OFFSET12
DEF #VAL125 #DAC5_ADDR OR #OFFSET12
DEF #VAL126 #DAC6_ADDR OR #OFFSET12
DEF #VAL127 #DAC7_ADDR OR #OFFSET12

DEF #VAL130 #DAC0_ADDR OR #OFFSET13
DEF #VAL131 #DAC1_ADDR OR #OFFSET13
DEF #VAL132 #DAC2_ADDR OR #OFFSET13
DEF #VAL133 #DAC3_ADDR OR #OFFSET13
DEF #VAL134 #DAC4_ADDR OR #OFFSET13
DEF #VAL135 #DAC5_ADDR OR #OFFSET13
DEF #VAL136 #DAC6_ADDR OR #OFFSET13
DEF #VAL137 #DAC7_ADDR OR #OFFSET13

DEF #VAL140 #DAC0_ADDR OR #OFFSET14
DEF #VAL141 #DAC1_ADDR OR #OFFSET14
DEF #VAL142 #DAC2_ADDR OR #OFFSET14
DEF #VAL143 #DAC3_ADDR OR #OFFSET14
DEF #VAL144 #DAC4_ADDR OR #OFFSET14
DEF #VAL145 #DAC5_ADDR OR #OFFSET14
DEF #VAL146 #DAC6_ADDR OR #OFFSET14
DEF #VAL147 #DAC7_ADDR OR #OFFSET14

DEF #VAL150 #DAC0_ADDR OR #OFFSET15
DEF #VAL151 #DAC1_ADDR OR #OFFSET15
DEF #VAL152 #DAC2_ADDR OR #OFFSET15
DEF #VAL153 #DAC3_ADDR OR #OFFSET15
DEF #VAL154 #DAC4_ADDR OR #OFFSET15
DEF #VAL155 #DAC5_ADDR OR #OFFSET15
DEF #VAL156 #DAC6_ADDR OR #OFFSET15
DEF #VAL157 #DAC7_ADDR OR #OFFSET15

DEF #VAL160 #DAC0_ADDR OR #OFFSET16
DEF #VAL161 #DAC1_ADDR OR #OFFSET16
DEF #VAL162 #DAC2_ADDR OR #OFFSET16
DEF #VAL163 #DAC3_ADDR OR #OFFSET16
DEF #VAL164 #DAC4_ADDR OR #OFFSET16
DEF #VAL165 #DAC5_ADDR OR #OFFSET16
DEF #VAL166 #DAC6_ADDR OR #OFFSET16
DEF #VAL167 #DAC7_ADDR OR #OFFSET16

DEF #VAL170 #DAC0_ADDR OR #OFFSET17
DEF #VAL171 #DAC1_ADDR OR #OFFSET17
DEF #VAL172 #DAC2_ADDR OR #OFFSET17
DEF #VAL173 #DAC3_ADDR OR #OFFSET17
DEF #VAL174 #DAC4_ADDR OR #OFFSET17
DEF #VAL175 #DAC5_ADDR OR #OFFSET17
DEF #VAL176 #DAC6_ADDR OR #OFFSET17
DEF #VAL177 #DAC7_ADDR OR #OFFSET17

DEF #VAL180 #DAC0_ADDR OR #OFFSET18
DEF #VAL181 #DAC1_ADDR OR #OFFSET18
DEF #VAL182 #DAC2_ADDR OR #OFFSET18
DEF #VAL183 #DAC3_ADDR OR #OFFSET18
DEF #VAL184 #DAC4_ADDR OR #OFFSET18
DEF #VAL185 #DAC5_ADDR OR #OFFSET18
DEF #VAL186 #DAC6_ADDR OR #OFFSET18
DEF #VAL187 #DAC7_ADDR OR #OFFSET18

DEF #VAL190 #DAC0_ADDR OR #OFFSET19
DEF #VAL191 #DAC1_ADDR OR #OFFSET19
DEF #VAL192 #DAC2_ADDR OR #OFFSET19
DEF #VAL193 #DAC3_ADDR OR #OFFSET19
DEF #VAL194 #DAC4_ADDR OR #OFFSET19
DEF #VAL195 #DAC5_ADDR OR #OFFSET19
DEF #VAL196 #DAC6_ADDR OR #OFFSET19
DEF #VAL197 #DAC7_ADDR OR #OFFSET19

DEF #VAL1A0 #DAC0_ADDR OR #OFFSET1A
DEF #VAL1A1 #DAC1_ADDR OR #OFFSET1A
DEF #VAL1A2 #DAC2_ADDR OR #OFFSET1A
DEF #VAL1A3 #DAC3_ADDR OR #OFFSET1A
DEF #VAL1A4 #DAC4_ADDR OR #OFFSET1A
DEF #VAL1A5 #DAC5_ADDR OR #OFFSET1A
DEF #VAL1A6 #DAC6_ADDR OR #OFFSET1A
DEF #VAL1A7 #DAC7_ADDR OR #OFFSET1A

DEF #VAL1B0 #DAC0_ADDR OR #OFFSET1B
DEF #VAL1B1 #DAC1_ADDR OR #OFFSET1B
DEF #VAL1B2 #DAC2_ADDR OR #OFFSET1B
DEF #VAL1B3 #DAC3_ADDR OR #OFFSET1B
DEF #VAL1B4 #DAC4_ADDR OR #OFFSET1B
DEF #VAL1B5 #DAC5_ADDR OR #OFFSET1B
DEF #VAL1B6 #DAC6_ADDR OR #OFFSET1B
DEF #VAL1B7 #DAC7_ADDR OR #OFFSET1B

DEF #VAL1C0 #DAC0_ADDR OR #OFFSET1C
DEF #VAL1C1 #DAC1_ADDR OR #OFFSET1C
DEF #VAL1C2 #DAC2_ADDR OR #OFFSET1C
DEF #VAL1C3 #DAC3_ADDR OR #OFFSET1C
DEF #VAL1C4 #DAC4_ADDR OR #OFFSET1C
DEF #VAL1C5 #DAC5_ADDR OR #OFFSET1C
DEF #VAL1C6 #DAC6_ADDR OR #OFFSET1C
DEF #VAL1C7 #DAC7_ADDR OR #OFFSET1C

DEF #VAL1D0 #DAC0_ADDR OR #OFFSET1D
DEF #VAL1D1 #DAC1_ADDR OR #OFFSET1D
DEF #VAL1D2 #DAC2_ADDR OR #OFFSET1D
DEF #VAL1D3 #DAC3_ADDR OR #OFFSET1D
DEF #VAL1D4 #DAC4_ADDR OR #OFFSET1D
DEF #VAL1D5 #DAC5_ADDR OR #OFFSET1D
DEF #VAL1D6 #DAC6_ADDR OR #OFFSET1D
DEF #VAL1D7 #DAC7_ADDR OR #OFFSET1D

DEF #VAL1E0 #DAC0_ADDR OR #OFFSET1E
DEF #VAL1E1 #DAC1_ADDR OR #OFFSET1E
DEF #VAL1E2 #DAC2_ADDR OR #OFFSET1E
DEF #VAL1E3 #DAC3_ADDR OR #OFFSET1E
DEF #VAL1E4 #DAC4_ADDR OR #OFFSET1E
DEF #VAL1E5 #DAC5_ADDR OR #OFFSET1E
DEF #VAL1E6 #DAC6_ADDR OR #OFFSET1E
DEF #VAL1E7 #DAC7_ADDR OR #OFFSET1E

DEF #VAL1F0 #DAC0_ADDR OR #OFFSET1F
DEF #VAL1F1 #DAC1_ADDR OR #OFFSET1F
DEF #VAL1F2 #DAC2_ADDR OR #OFFSET1F
DEF #VAL1F3 #DAC3_ADDR OR #OFFSET1F
DEF #VAL1F4 #DAC4_ADDR OR #OFFSET1F
DEF #VAL1F5 #DAC5_ADDR OR #OFFSET1F
DEF #VAL1F6 #DAC6_ADDR OR #OFFSET1F
DEF #VAL1F7 #DAC7_ADDR OR #OFFSET1F

DEF #VAL200 #DAC0_ADDR OR #OFFSET20
DEF #VAL201 #DAC1_ADDR OR #OFFSET20
DEF #VAL202 #DAC2_ADDR OR #OFFSET20
DEF #VAL203 #DAC3_ADDR OR #OFFSET20
DEF #VAL204 #DAC4_ADDR OR #OFFSET20
DEF #VAL205 #DAC5_ADDR OR #OFFSET20
DEF #VAL206 #DAC6_ADDR OR #OFFSET20
DEF #VAL207 #DAC7_ADDR OR #OFFSET20

DEF #VAL210 #DAC0_ADDR OR #OFFSET21
DEF #VAL211 #DAC1_ADDR OR #OFFSET21
DEF #VAL212 #DAC2_ADDR OR #OFFSET21
DEF #VAL213 #DAC3_ADDR OR #OFFSET21
DEF #VAL214 #DAC4_ADDR OR #OFFSET21
DEF #VAL215 #DAC5_ADDR OR #OFFSET21
DEF #VAL216 #DAC6_ADDR OR #OFFSET21
DEF #VAL217 #DAC7_ADDR OR #OFFSET21

DEF #VAL220 #DAC0_ADDR OR #OFFSET22
DEF #VAL221 #DAC1_ADDR OR #OFFSET22
DEF #VAL222 #DAC2_ADDR OR #OFFSET22
DEF #VAL223 #DAC3_ADDR OR #OFFSET22
DEF #VAL224 #DAC4_ADDR OR #OFFSET22
DEF #VAL225 #DAC5_ADDR OR #OFFSET22
DEF #VAL226 #DAC6_ADDR OR #OFFSET22
DEF #VAL227 #DAC7_ADDR OR #OFFSET22

DEF #VAL230 #DAC0_ADDR OR #OFFSET23
DEF #VAL231 #DAC1_ADDR OR #OFFSET23
DEF #VAL232 #DAC2_ADDR OR #OFFSET23
DEF #VAL233 #DAC3_ADDR OR #OFFSET23
DEF #VAL234 #DAC4_ADDR OR #OFFSET23
DEF #VAL235 #DAC5_ADDR OR #OFFSET23
DEF #VAL236 #DAC6_ADDR OR #OFFSET23
DEF #VAL237 #DAC7_ADDR OR #OFFSET23

DEF #VAL240 #DAC0_ADDR OR #OFFSET24
DEF #VAL241 #DAC1_ADDR OR #OFFSET24
DEF #VAL242 #DAC2_ADDR OR #OFFSET24
DEF #VAL243 #DAC3_ADDR OR #OFFSET24
DEF #VAL244 #DAC4_ADDR OR #OFFSET24
DEF #VAL245 #DAC5_ADDR OR #OFFSET24
DEF #VAL246 #DAC6_ADDR OR #OFFSET24
DEF #VAL247 #DAC7_ADDR OR #OFFSET24

DEF #VAL250 #DAC0_ADDR OR #OFFSET25
DEF #VAL251 #DAC1_ADDR OR #OFFSET25
DEF #VAL252 #DAC2_ADDR OR #OFFSET25
DEF #VAL253 #DAC3_ADDR OR #OFFSET25
DEF #VAL254 #DAC4_ADDR OR #OFFSET25
DEF #VAL255 #DAC5_ADDR OR #OFFSET25
DEF #VAL256 #DAC6_ADDR OR #OFFSET25
DEF #VAL257 #DAC7_ADDR OR #OFFSET25

DEF #VAL260 #DAC0_ADDR OR #OFFSET26
DEF #VAL261 #DAC1_ADDR OR #OFFSET26
DEF #VAL262 #DAC2_ADDR OR #OFFSET26
DEF #VAL263 #DAC3_ADDR OR #OFFSET26
DEF #VAL264 #DAC4_ADDR OR #OFFSET26
DEF #VAL265 #DAC5_ADDR OR #OFFSET26
DEF #VAL266 #DAC6_ADDR OR #OFFSET26
DEF #VAL267 #DAC7_ADDR OR #OFFSET26

DEF #VAL270 #DAC0_ADDR OR #OFFSET27
DEF #VAL271 #DAC1_ADDR OR #OFFSET27
DEF #VAL272 #DAC2_ADDR OR #OFFSET27
DEF #VAL273 #DAC3_ADDR OR #OFFSET27
DEF #VAL274 #DAC4_ADDR OR #OFFSET27
DEF #VAL275 #DAC5_ADDR OR #OFFSET27
DEF #VAL276 #DAC6_ADDR OR #OFFSET27
DEF #VAL277 #DAC7_ADDR OR #OFFSET27

DEF #VAL280 #DAC0_ADDR OR #OFFSET28
DEF #VAL281 #DAC1_ADDR OR #OFFSET28
DEF #VAL282 #DAC2_ADDR OR #OFFSET28
DEF #VAL283 #DAC3_ADDR OR #OFFSET28
DEF #VAL284 #DAC4_ADDR OR #OFFSET28
DEF #VAL285 #DAC5_ADDR OR #OFFSET28
DEF #VAL286 #DAC6_ADDR OR #OFFSET28
DEF #VAL287 #DAC7_ADDR OR #OFFSET28

DEF #VAL290 #DAC0_ADDR OR #OFFSET29
DEF #VAL291 #DAC1_ADDR OR #OFFSET29
DEF #VAL292 #DAC2_ADDR OR #OFFSET29
DEF #VAL293 #DAC3_ADDR OR #OFFSET29
DEF #VAL294 #DAC4_ADDR OR #OFFSET29
DEF #VAL295 #DAC5_ADDR OR #OFFSET29
DEF #VAL296 #DAC6_ADDR OR #OFFSET29
DEF #VAL297 #DAC7_ADDR OR #OFFSET29

DEF #VAL2A0 #DAC0_ADDR OR #OFFSET2A
DEF #VAL2A1 #DAC1_ADDR OR #OFFSET2A
DEF #VAL2A2 #DAC2_ADDR OR #OFFSET2A
DEF #VAL2A3 #DAC3_ADDR OR #OFFSET2A
DEF #VAL2A4 #DAC4_ADDR OR #OFFSET2A
DEF #VAL2A5 #DAC5_ADDR OR #OFFSET2A
DEF #VAL2A6 #DAC6_ADDR OR #OFFSET2A
DEF #VAL2A7 #DAC7_ADDR OR #OFFSET2A

DEF #VAL2B0 #DAC0_ADDR OR #OFFSET2B
DEF #VAL2B1 #DAC1_ADDR OR #OFFSET2B
DEF #VAL2B2 #DAC2_ADDR OR #OFFSET2B
DEF #VAL2B3 #DAC3_ADDR OR #OFFSET2B
DEF #VAL2B4 #DAC4_ADDR OR #OFFSET2B
DEF #VAL2B5 #DAC5_ADDR OR #OFFSET2B
DEF #VAL2B6 #DAC6_ADDR OR #OFFSET2B
DEF #VAL2B7 #DAC7_ADDR OR #OFFSET2B

DEF #VAL2C0 #DAC0_ADDR OR #OFFSET2C
DEF #VAL2C1 #DAC1_ADDR OR #OFFSET2C
DEF #VAL2C2 #DAC2_ADDR OR #OFFSET2C
DEF #VAL2C3 #DAC3_ADDR OR #OFFSET2C
DEF #VAL2C4 #DAC4_ADDR OR #OFFSET2C
DEF #VAL2C5 #DAC5_ADDR OR #OFFSET2C
DEF #VAL2C6 #DAC6_ADDR OR #OFFSET2C
DEF #VAL2C7 #DAC7_ADDR OR #OFFSET2C

DEF #VAL2D0 #DAC0_ADDR OR #OFFSET2D
DEF #VAL2D1 #DAC1_ADDR OR #OFFSET2D
DEF #VAL2D2 #DAC2_ADDR OR #OFFSET2D
DEF #VAL2D3 #DAC3_ADDR OR #OFFSET2D
DEF #VAL2D4 #DAC4_ADDR OR #OFFSET2D
DEF #VAL2D5 #DAC5_ADDR OR #OFFSET2D
DEF #VAL2D6 #DAC6_ADDR OR #OFFSET2D
DEF #VAL2D7 #DAC7_ADDR OR #OFFSET2D

DEF #VAL2E0 #DAC0_ADDR OR #OFFSET2E
DEF #VAL2E1 #DAC1_ADDR OR #OFFSET2E
DEF #VAL2E2 #DAC2_ADDR OR #OFFSET2E
DEF #VAL2E3 #DAC3_ADDR OR #OFFSET2E
DEF #VAL2E4 #DAC4_ADDR OR #OFFSET2E
DEF #VAL2E5 #DAC5_ADDR OR #OFFSET2E
DEF #VAL2E6 #DAC6_ADDR OR #OFFSET2E
DEF #VAL2E7 #DAC7_ADDR OR #OFFSET2E

DEF #VAL2F0 #DAC0_ADDR OR #OFFSET2F
DEF #VAL2F1 #DAC1_ADDR OR #OFFSET2F
DEF #VAL2F2 #DAC2_ADDR OR #OFFSET2F
DEF #VAL2F3 #DAC3_ADDR OR #OFFSET2F
DEF #VAL2F4 #DAC4_ADDR OR #OFFSET2F
DEF #VAL2F5 #DAC5_ADDR OR #OFFSET2F
DEF #VAL2F6 #DAC6_ADDR OR #OFFSET2F
DEF #VAL2F7 #DAC7_ADDR OR #OFFSET2F

DEF #VAL300 #DAC0_ADDR OR #OFFSET30
DEF #VAL301 #DAC1_ADDR OR #OFFSET30
DEF #VAL302 #DAC2_ADDR OR #OFFSET30
DEF #VAL303 #DAC3_ADDR OR #OFFSET30
DEF #VAL304 #DAC4_ADDR OR #OFFSET30
DEF #VAL305 #DAC5_ADDR OR #OFFSET30
DEF #VAL306 #DAC6_ADDR OR #OFFSET30
DEF #VAL307 #DAC7_ADDR OR #OFFSET30

DEF #VAL310 #DAC0_ADDR OR #OFFSET31
DEF #VAL311 #DAC1_ADDR OR #OFFSET31
DEF #VAL312 #DAC2_ADDR OR #OFFSET31
DEF #VAL313 #DAC3_ADDR OR #OFFSET31
DEF #VAL314 #DAC4_ADDR OR #OFFSET31
DEF #VAL315 #DAC5_ADDR OR #OFFSET31
DEF #VAL316 #DAC6_ADDR OR #OFFSET31
DEF #VAL317 #DAC7_ADDR OR #OFFSET31

DEF #VAL320 #DAC0_ADDR OR #OFFSET32
DEF #VAL321 #DAC1_ADDR OR #OFFSET32
DEF #VAL322 #DAC2_ADDR OR #OFFSET32
DEF #VAL323 #DAC3_ADDR OR #OFFSET32
DEF #VAL324 #DAC4_ADDR OR #OFFSET32
DEF #VAL325 #DAC5_ADDR OR #OFFSET32
DEF #VAL326 #DAC6_ADDR OR #OFFSET32
DEF #VAL327 #DAC7_ADDR OR #OFFSET32

DEF #VAL330 #DAC0_ADDR OR #OFFSET33
DEF #VAL331 #DAC1_ADDR OR #OFFSET33
DEF #VAL332 #DAC2_ADDR OR #OFFSET33
DEF #VAL333 #DAC3_ADDR OR #OFFSET33
DEF #VAL334 #DAC4_ADDR OR #OFFSET33
DEF #VAL335 #DAC5_ADDR OR #OFFSET33
DEF #VAL336 #DAC6_ADDR OR #OFFSET33
DEF #VAL337 #DAC7_ADDR OR #OFFSET33

DEF #VAL340 #DAC0_ADDR OR #OFFSET34
DEF #VAL341 #DAC1_ADDR OR #OFFSET34
DEF #VAL342 #DAC2_ADDR OR #OFFSET34
DEF #VAL343 #DAC3_ADDR OR #OFFSET34
DEF #VAL344 #DAC4_ADDR OR #OFFSET34
DEF #VAL345 #DAC5_ADDR OR #OFFSET34
DEF #VAL346 #DAC6_ADDR OR #OFFSET34
DEF #VAL347 #DAC7_ADDR OR #OFFSET34

DEF #VAL350 #DAC0_ADDR OR #OFFSET35
DEF #VAL351 #DAC1_ADDR OR #OFFSET35
DEF #VAL352 #DAC2_ADDR OR #OFFSET35
DEF #VAL353 #DAC3_ADDR OR #OFFSET35
DEF #VAL354 #DAC4_ADDR OR #OFFSET35
DEF #VAL355 #DAC5_ADDR OR #OFFSET35
DEF #VAL356 #DAC6_ADDR OR #OFFSET35
DEF #VAL357 #DAC7_ADDR OR #OFFSET35

DEF #VAL360 #DAC0_ADDR OR #OFFSET36
DEF #VAL361 #DAC1_ADDR OR #OFFSET36
DEF #VAL362 #DAC2_ADDR OR #OFFSET36
DEF #VAL363 #DAC3_ADDR OR #OFFSET36
DEF #VAL364 #DAC4_ADDR OR #OFFSET36
DEF #VAL365 #DAC5_ADDR OR #OFFSET36
DEF #VAL366 #DAC6_ADDR OR #OFFSET36
DEF #VAL367 #DAC7_ADDR OR #OFFSET36

DEF #VAL370 #DAC0_ADDR OR #OFFSET37
DEF #VAL371 #DAC1_ADDR OR #OFFSET37
DEF #VAL372 #DAC2_ADDR OR #OFFSET37
DEF #VAL373 #DAC3_ADDR OR #OFFSET37
DEF #VAL374 #DAC4_ADDR OR #OFFSET37
DEF #VAL375 #DAC5_ADDR OR #OFFSET37
DEF #VAL376 #DAC6_ADDR OR #OFFSET37
DEF #VAL377 #DAC7_ADDR OR #OFFSET37

DEF #VAL380 #DAC0_ADDR OR #OFFSET38
DEF #VAL381 #DAC1_ADDR OR #OFFSET38
DEF #VAL382 #DAC2_ADDR OR #OFFSET38
DEF #VAL383 #DAC3_ADDR OR #OFFSET38
DEF #VAL384 #DAC4_ADDR OR #OFFSET38
DEF #VAL385 #DAC5_ADDR OR #OFFSET38
DEF #VAL386 #DAC6_ADDR OR #OFFSET38
DEF #VAL387 #DAC7_ADDR OR #OFFSET38

DEF #VAL390 #DAC0_ADDR OR #OFFSET39
DEF #VAL391 #DAC1_ADDR OR #OFFSET39
DEF #VAL392 #DAC2_ADDR OR #OFFSET39
DEF #VAL393 #DAC3_ADDR OR #OFFSET39
DEF #VAL394 #DAC4_ADDR OR #OFFSET39
DEF #VAL395 #DAC5_ADDR OR #OFFSET39
DEF #VAL396 #DAC6_ADDR OR #OFFSET39
DEF #VAL397 #DAC7_ADDR OR #OFFSET39

DEF #VAL3A0 #DAC0_ADDR OR #OFFSET3A
DEF #VAL3A1 #DAC1_ADDR OR #OFFSET3A
DEF #VAL3A2 #DAC2_ADDR OR #OFFSET3A
DEF #VAL3A3 #DAC3_ADDR OR #OFFSET3A
DEF #VAL3A4 #DAC4_ADDR OR #OFFSET3A
DEF #VAL3A5 #DAC5_ADDR OR #OFFSET3A
DEF #VAL3A6 #DAC6_ADDR OR #OFFSET3A
DEF #VAL3A7 #DAC7_ADDR OR #OFFSET3A

DEF #VAL3B0 #DAC0_ADDR OR #OFFSET3B
DEF #VAL3B1 #DAC1_ADDR OR #OFFSET3B
DEF #VAL3B2 #DAC2_ADDR OR #OFFSET3B
DEF #VAL3B3 #DAC3_ADDR OR #OFFSET3B
DEF #VAL3B4 #DAC4_ADDR OR #OFFSET3B
DEF #VAL3B5 #DAC5_ADDR OR #OFFSET3B
DEF #VAL3B6 #DAC6_ADDR OR #OFFSET3B
DEF #VAL3B7 #DAC7_ADDR OR #OFFSET3B

DEF #VAL3C0 #DAC0_ADDR OR #OFFSET3C
DEF #VAL3C1 #DAC1_ADDR OR #OFFSET3C
DEF #VAL3C2 #DAC2_ADDR OR #OFFSET3C
DEF #VAL3C3 #DAC3_ADDR OR #OFFSET3C
DEF #VAL3C4 #DAC4_ADDR OR #OFFSET3C
DEF #VAL3C5 #DAC5_ADDR OR #OFFSET3C
DEF #VAL3C6 #DAC6_ADDR OR #OFFSET3C
DEF #VAL3C7 #DAC7_ADDR OR #OFFSET3C

DEF #VAL3D0 #DAC0_ADDR OR #OFFSET3D
DEF #VAL3D1 #DAC1_ADDR OR #OFFSET3D
DEF #VAL3D2 #DAC2_ADDR OR #OFFSET3D
DEF #VAL3D3 #DAC3_ADDR OR #OFFSET3D
DEF #VAL3D4 #DAC4_ADDR OR #OFFSET3D
DEF #VAL3D5 #DAC5_ADDR OR #OFFSET3D
DEF #VAL3D6 #DAC6_ADDR OR #OFFSET3D
DEF #VAL3D7 #DAC7_ADDR OR #OFFSET3D

DEF #VAL3E0 #DAC0_ADDR OR #OFFSET3E
DEF #VAL3E1 #DAC1_ADDR OR #OFFSET3E
DEF #VAL3E2 #DAC2_ADDR OR #OFFSET3E
DEF #VAL3E3 #DAC3_ADDR OR #OFFSET3E
DEF #VAL3E4 #DAC4_ADDR OR #OFFSET3E
DEF #VAL3E5 #DAC5_ADDR OR #OFFSET3E
DEF #VAL3E6 #DAC6_ADDR OR #OFFSET3E
DEF #VAL3E7 #DAC7_ADDR OR #OFFSET3E

DEF #VAL3F0 #DAC0_ADDR OR #OFFSET3F
DEF #VAL3F1 #DAC1_ADDR OR #OFFSET3F
DEF #VAL3F2 #DAC2_ADDR OR #OFFSET3F
DEF #VAL3F3 #DAC3_ADDR OR #OFFSET3F
DEF #VAL3F4 #DAC4_ADDR OR #OFFSET3F
DEF #VAL3F5 #DAC5_ADDR OR #OFFSET3F
DEF #VAL3F6 #DAC6_ADDR OR #OFFSET3F
DEF #VAL3F7 #DAC7_ADDR OR #OFFSET3F

********************************
** PATTERN MEMORY DEFINITIONS **
********************************
** PATTERN MEMORY SEGMENTATION MAP
DEF #PATSEG_00      x0000           * Pattern memory origin - Initialization stuff
DEF #PATSEG_10      x0010
DEF #PATSEG_20      x0020

ORG PAT #PATSEG_00                    * ********* GENERAL CONSTANTS KEPT IN PAT MEM ********* 
PAT #KILL_EXPFLG    #KILL_EXPFLG      * We can use the same label name here because they are in different contexts
PAT #STRT_INTCNTR   #STRT_INTCNTR     * The definition earlier points to a data value. The label here points to
PAT #STOP_INTCNTR   #STOP_INTCNTR     * a pattern memory address
PAT #CDSCMD0        #CDSCMD0
PAT #CDSCMD1        #CDSCMD1
PAT #CDSCMD2        #CDSCMD2
PAT #CDSCMD3        #CDSCMD3

ORG PAT #PATSEG_10
PAT #DOPLO  #DOPLO
PAT #DOPHI  #DOPHI

ORG PAT #PATSEG_20                    * BEGINNING OF OFFSET DAC DATA
PAT #VAL000 #VAL000
PAT #VAL001 #VAL001
PAT #VAL002 #VAL002
PAT #VAL003 #VAL003
PAT #VAL004 #VAL004
PAT #VAL005 #VAL005
PAT #VAL006 #VAL006
PAT #VAL007 #VAL007
                   
PAT #VAL010 #VAL010
PAT #VAL011 #VAL011
PAT #VAL012 #VAL012
PAT #VAL013 #VAL013
PAT #VAL014 #VAL014
PAT #VAL015 #VAL015
PAT #VAL016 #VAL016
PAT #VAL017 #VAL017
                   
PAT #VAL020 #VAL020
PAT #VAL021 #VAL021
PAT #VAL022 #VAL022
PAT #VAL023 #VAL023
PAT #VAL024 #VAL024
PAT #VAL025 #VAL025
PAT #VAL026 #VAL026
PAT #VAL027 #VAL027
                   
PAT #VAL030 #VAL030
PAT #VAL031 #VAL031
PAT #VAL032 #VAL032
PAT #VAL033 #VAL033
PAT #VAL034 #VAL034
PAT #VAL035 #VAL035
PAT #VAL036 #VAL036
PAT #VAL037 #VAL037
                   
PAT #VAL040 #VAL040
PAT #VAL041 #VAL041
PAT #VAL042 #VAL042
PAT #VAL043 #VAL043
PAT #VAL044 #VAL044
PAT #VAL045 #VAL045
PAT #VAL046 #VAL046
PAT #VAL047 #VAL047
                   
PAT #VAL050 #VAL050
PAT #VAL051 #VAL051
PAT #VAL052 #VAL052
PAT #VAL053 #VAL053
PAT #VAL054 #VAL054
PAT #VAL055 #VAL055
PAT #VAL056 #VAL056
PAT #VAL057 #VAL057
                   
PAT #VAL060 #VAL060
PAT #VAL061 #VAL061
PAT #VAL062 #VAL062
PAT #VAL063 #VAL063
PAT #VAL064 #VAL064
PAT #VAL065 #VAL065
PAT #VAL066 #VAL066
PAT #VAL067 #VAL067

PAT #VAL070 #VAL070
PAT #VAL071 #VAL071
PAT #VAL072 #VAL072
PAT #VAL073 #VAL073
PAT #VAL074 #VAL074
PAT #VAL075 #VAL075
PAT #VAL076 #VAL076
PAT #VAL077 #VAL077

PAT #VAL080 #VAL080
PAT #VAL081 #VAL081
PAT #VAL082 #VAL082
PAT #VAL083 #VAL083
PAT #VAL084 #VAL084
PAT #VAL085 #VAL085
PAT #VAL086 #VAL086
PAT #VAL087 #VAL087
                   
PAT #VAL090 #VAL090
PAT #VAL091 #VAL091
PAT #VAL092 #VAL092
PAT #VAL093 #VAL093
PAT #VAL094 #VAL094
PAT #VAL095 #VAL095
PAT #VAL096 #VAL096
PAT #VAL097 #VAL097
                   
PAT #VAL0A0 #VAL0A0
PAT #VAL0A1 #VAL0A1
PAT #VAL0A2 #VAL0A2
PAT #VAL0A3 #VAL0A3
PAT #VAL0A4 #VAL0A4
PAT #VAL0A5 #VAL0A5
PAT #VAL0A6 #VAL0A6
PAT #VAL0A7 #VAL0A7
                   
PAT #VAL0B0 #VAL0B0
PAT #VAL0B1 #VAL0B1
PAT #VAL0B2 #VAL0B2
PAT #VAL0B3 #VAL0B3
PAT #VAL0B4 #VAL0B4
PAT #VAL0B5 #VAL0B5
PAT #VAL0B6 #VAL0B6
PAT #VAL0B7 #VAL0B7
                   
PAT #VAL0C0 #VAL0C0
PAT #VAL0C1 #VAL0C1
PAT #VAL0C2 #VAL0C2
PAT #VAL0C3 #VAL0C3
PAT #VAL0C4 #VAL0C4
PAT #VAL0C5 #VAL0C5
PAT #VAL0C6 #VAL0C6
PAT #VAL0C7 #VAL0C7
                   
PAT #VAL0D0 #VAL0D0
PAT #VAL0D1 #VAL0D1
PAT #VAL0D2 #VAL0D2
PAT #VAL0D3 #VAL0D3
PAT #VAL0D4 #VAL0D4
PAT #VAL0D5 #VAL0D5
PAT #VAL0D6 #VAL0D6
PAT #VAL0D7 #VAL0D7
                   
PAT #VAL0E0 #VAL0E0
PAT #VAL0E1 #VAL0E1
PAT #VAL0E2 #VAL0E2
PAT #VAL0E3 #VAL0E3
PAT #VAL0E4 #VAL0E4
PAT #VAL0E5 #VAL0E5
PAT #VAL0E6 #VAL0E6
PAT #VAL0E7 #VAL0E7

PAT #VAL0F0 #VAL0F0
PAT #VAL0F1 #VAL0F1
PAT #VAL0F2 #VAL0F2
PAT #VAL0F3 #VAL0F3
PAT #VAL0F4 #VAL0F4
PAT #VAL0F5 #VAL0F5
PAT #VAL0F6 #VAL0F6
PAT #VAL0F7 #VAL0F7

PAT #VAL100 #VAL100
PAT #VAL101 #VAL101
PAT #VAL102 #VAL102
PAT #VAL103 #VAL103
PAT #VAL104 #VAL104
PAT #VAL105 #VAL105
PAT #VAL106 #VAL106
PAT #VAL107 #VAL107
                   
PAT #VAL110 #VAL110
PAT #VAL111 #VAL111
PAT #VAL112 #VAL112
PAT #VAL113 #VAL113
PAT #VAL114 #VAL114
PAT #VAL115 #VAL115
PAT #VAL116 #VAL116
PAT #VAL117 #VAL117
                   
PAT #VAL120 #VAL120
PAT #VAL121 #VAL121
PAT #VAL122 #VAL122
PAT #VAL123 #VAL123
PAT #VAL124 #VAL124
PAT #VAL125 #VAL125
PAT #VAL126 #VAL126
PAT #VAL127 #VAL127
                   
PAT #VAL130 #VAL130
PAT #VAL131 #VAL131
PAT #VAL132 #VAL132
PAT #VAL133 #VAL133
PAT #VAL134 #VAL134
PAT #VAL135 #VAL135
PAT #VAL136 #VAL136
PAT #VAL137 #VAL137
                   
PAT #VAL140 #VAL140
PAT #VAL141 #VAL141
PAT #VAL142 #VAL142
PAT #VAL143 #VAL143
PAT #VAL144 #VAL144
PAT #VAL145 #VAL145
PAT #VAL146 #VAL146
PAT #VAL147 #VAL147
                   
PAT #VAL150 #VAL150
PAT #VAL151 #VAL151
PAT #VAL152 #VAL152
PAT #VAL153 #VAL153
PAT #VAL154 #VAL154
PAT #VAL155 #VAL155
PAT #VAL156 #VAL156
PAT #VAL157 #VAL157
                   
PAT #VAL160 #VAL160
PAT #VAL161 #VAL161
PAT #VAL162 #VAL162
PAT #VAL163 #VAL163
PAT #VAL164 #VAL164
PAT #VAL165 #VAL165
PAT #VAL166 #VAL166
PAT #VAL167 #VAL167

PAT #VAL170 #VAL170
PAT #VAL171 #VAL171
PAT #VAL172 #VAL172
PAT #VAL173 #VAL173
PAT #VAL174 #VAL174
PAT #VAL175 #VAL175
PAT #VAL176 #VAL176
PAT #VAL177 #VAL177

PAT #VAL180 #VAL180
PAT #VAL181 #VAL181
PAT #VAL182 #VAL182
PAT #VAL183 #VAL183
PAT #VAL184 #VAL184
PAT #VAL185 #VAL185
PAT #VAL186 #VAL186
PAT #VAL187 #VAL187
                   
PAT #VAL190 #VAL190
PAT #VAL191 #VAL191
PAT #VAL192 #VAL192
PAT #VAL193 #VAL193
PAT #VAL194 #VAL194
PAT #VAL195 #VAL195
PAT #VAL196 #VAL196
PAT #VAL197 #VAL197
                   
PAT #VAL1A0 #VAL1A0
PAT #VAL1A1 #VAL1A1
PAT #VAL1A2 #VAL1A2
PAT #VAL1A3 #VAL1A3
PAT #VAL1A4 #VAL1A4
PAT #VAL1A5 #VAL1A5
PAT #VAL1A6 #VAL1A6
PAT #VAL1A7 #VAL1A7
                   
PAT #VAL1B0 #VAL1B0
PAT #VAL1B1 #VAL1B1
PAT #VAL1B2 #VAL1B2
PAT #VAL1B3 #VAL1B3
PAT #VAL1B4 #VAL1B4
PAT #VAL1B5 #VAL1B5
PAT #VAL1B6 #VAL1B6
PAT #VAL1B7 #VAL1B7
                   
PAT #VAL1C0 #VAL1C0
PAT #VAL1C1 #VAL1C1
PAT #VAL1C2 #VAL1C2
PAT #VAL1C3 #VAL1C3
PAT #VAL1C4 #VAL1C4
PAT #VAL1C5 #VAL1C5
PAT #VAL1C6 #VAL1C6
PAT #VAL1C7 #VAL1C7
                   
PAT #VAL1D0 #VAL1D0
PAT #VAL1D1 #VAL1D1
PAT #VAL1D2 #VAL1D2
PAT #VAL1D3 #VAL1D3
PAT #VAL1D4 #VAL1D4
PAT #VAL1D5 #VAL1D5
PAT #VAL1D6 #VAL1D6
PAT #VAL1D7 #VAL1D7
                   
PAT #VAL1E0 #VAL1E0
PAT #VAL1E1 #VAL1E1
PAT #VAL1E2 #VAL1E2
PAT #VAL1E3 #VAL1E3
PAT #VAL1E4 #VAL1E4
PAT #VAL1E5 #VAL1E5
PAT #VAL1E6 #VAL1E6
PAT #VAL1E7 #VAL1E7

PAT #VAL1F0 #VAL1F0
PAT #VAL1F1 #VAL1F1
PAT #VAL1F2 #VAL1F2
PAT #VAL1F3 #VAL1F3
PAT #VAL1F4 #VAL1F4
PAT #VAL1F5 #VAL1F5
PAT #VAL1F6 #VAL1F6
PAT #VAL1F7 #VAL1F7

PAT #VAL200 #VAL200
PAT #VAL201 #VAL201
PAT #VAL202 #VAL202
PAT #VAL203 #VAL203
PAT #VAL204 #VAL204
PAT #VAL205 #VAL205
PAT #VAL206 #VAL206
PAT #VAL207 #VAL207
                   
PAT #VAL210 #VAL210
PAT #VAL211 #VAL211
PAT #VAL212 #VAL212
PAT #VAL213 #VAL213
PAT #VAL214 #VAL214
PAT #VAL215 #VAL215
PAT #VAL216 #VAL216
PAT #VAL217 #VAL217
                   
PAT #VAL220 #VAL220
PAT #VAL221 #VAL221
PAT #VAL222 #VAL222
PAT #VAL223 #VAL223
PAT #VAL224 #VAL224
PAT #VAL225 #VAL225
PAT #VAL226 #VAL226
PAT #VAL227 #VAL227
                   
PAT #VAL230 #VAL230
PAT #VAL231 #VAL231
PAT #VAL232 #VAL232
PAT #VAL233 #VAL233
PAT #VAL234 #VAL234
PAT #VAL235 #VAL235
PAT #VAL236 #VAL236
PAT #VAL237 #VAL237
                   
PAT #VAL240 #VAL240
PAT #VAL241 #VAL241
PAT #VAL242 #VAL242
PAT #VAL243 #VAL243
PAT #VAL244 #VAL244
PAT #VAL245 #VAL245
PAT #VAL246 #VAL246
PAT #VAL247 #VAL247
                   
PAT #VAL250 #VAL250
PAT #VAL251 #VAL251
PAT #VAL252 #VAL252
PAT #VAL253 #VAL253
PAT #VAL254 #VAL254
PAT #VAL255 #VAL255
PAT #VAL256 #VAL256
PAT #VAL257 #VAL257
                   
PAT #VAL260 #VAL260
PAT #VAL261 #VAL261
PAT #VAL262 #VAL262
PAT #VAL263 #VAL263
PAT #VAL264 #VAL264
PAT #VAL265 #VAL265
PAT #VAL266 #VAL266
PAT #VAL267 #VAL267

PAT #VAL270 #VAL270
PAT #VAL271 #VAL271
PAT #VAL272 #VAL272
PAT #VAL273 #VAL273
PAT #VAL274 #VAL274
PAT #VAL275 #VAL275
PAT #VAL276 #VAL276
PAT #VAL277 #VAL277

PAT #VAL280 #VAL280
PAT #VAL281 #VAL281
PAT #VAL282 #VAL282
PAT #VAL283 #VAL283
PAT #VAL284 #VAL284
PAT #VAL285 #VAL285
PAT #VAL286 #VAL286
PAT #VAL287 #VAL287
                   
PAT #VAL290 #VAL290
PAT #VAL291 #VAL291
PAT #VAL292 #VAL292
PAT #VAL293 #VAL293
PAT #VAL294 #VAL294
PAT #VAL295 #VAL295
PAT #VAL296 #VAL296
PAT #VAL297 #VAL297
                   
PAT #VAL2A0 #VAL2A0
PAT #VAL2A1 #VAL2A1
PAT #VAL2A2 #VAL2A2
PAT #VAL2A3 #VAL2A3
PAT #VAL2A4 #VAL2A4
PAT #VAL2A5 #VAL2A5
PAT #VAL2A6 #VAL2A6
PAT #VAL2A7 #VAL2A7
                   
PAT #VAL2B0 #VAL2B0
PAT #VAL2B1 #VAL2B1
PAT #VAL2B2 #VAL2B2
PAT #VAL2B3 #VAL2B3
PAT #VAL2B4 #VAL2B4
PAT #VAL2B5 #VAL2B5
PAT #VAL2B6 #VAL2B6
PAT #VAL2B7 #VAL2B7
                   
PAT #VAL2C0 #VAL2C0
PAT #VAL2C1 #VAL2C1
PAT #VAL2C2 #VAL2C2
PAT #VAL2C3 #VAL2C3
PAT #VAL2C4 #VAL2C4
PAT #VAL2C5 #VAL2C5
PAT #VAL2C6 #VAL2C6
PAT #VAL2C7 #VAL2C7
                   
PAT #VAL2D0 #VAL2D0
PAT #VAL2D1 #VAL2D1
PAT #VAL2D2 #VAL2D2
PAT #VAL2D3 #VAL2D3
PAT #VAL2D4 #VAL2D4
PAT #VAL2D5 #VAL2D5
PAT #VAL2D6 #VAL2D6
PAT #VAL2D7 #VAL2D7
                   
PAT #VAL2E0 #VAL2E0
PAT #VAL2E1 #VAL2E1
PAT #VAL2E2 #VAL2E2
PAT #VAL2E3 #VAL2E3
PAT #VAL2E4 #VAL2E4
PAT #VAL2E5 #VAL2E5
PAT #VAL2E6 #VAL2E6
PAT #VAL2E7 #VAL2E7

PAT #VAL2F0 #VAL2F0
PAT #VAL2F1 #VAL2F1
PAT #VAL2F2 #VAL2F2
PAT #VAL2F3 #VAL2F3
PAT #VAL2F4 #VAL2F4
PAT #VAL2F5 #VAL2F5
PAT #VAL2F6 #VAL2F6
PAT #VAL2F7 #VAL2F7

PAT #VAL300 #VAL300
PAT #VAL301 #VAL301
PAT #VAL302 #VAL302
PAT #VAL303 #VAL303
PAT #VAL304 #VAL304
PAT #VAL305 #VAL305
PAT #VAL306 #VAL306
PAT #VAL307 #VAL307
                   
PAT #VAL310 #VAL310
PAT #VAL311 #VAL311
PAT #VAL312 #VAL312
PAT #VAL313 #VAL313
PAT #VAL314 #VAL314
PAT #VAL315 #VAL315
PAT #VAL316 #VAL316
PAT #VAL317 #VAL317
                   
PAT #VAL320 #VAL320
PAT #VAL321 #VAL321
PAT #VAL322 #VAL322
PAT #VAL323 #VAL323
PAT #VAL324 #VAL324
PAT #VAL325 #VAL325
PAT #VAL326 #VAL326
PAT #VAL327 #VAL327
                   
PAT #VAL330 #VAL330
PAT #VAL331 #VAL331
PAT #VAL332 #VAL332
PAT #VAL333 #VAL333
PAT #VAL334 #VAL334
PAT #VAL335 #VAL335
PAT #VAL336 #VAL336
PAT #VAL337 #VAL337
                   
PAT #VAL340 #VAL340
PAT #VAL341 #VAL341
PAT #VAL342 #VAL342
PAT #VAL343 #VAL343
PAT #VAL344 #VAL344
PAT #VAL345 #VAL345
PAT #VAL346 #VAL346
PAT #VAL347 #VAL347
                   
PAT #VAL350 #VAL350
PAT #VAL351 #VAL351
PAT #VAL352 #VAL352
PAT #VAL353 #VAL353
PAT #VAL354 #VAL354
PAT #VAL355 #VAL355
PAT #VAL356 #VAL356
PAT #VAL357 #VAL357
                   
PAT #VAL360 #VAL360
PAT #VAL361 #VAL361
PAT #VAL362 #VAL362
PAT #VAL363 #VAL363
PAT #VAL364 #VAL364
PAT #VAL365 #VAL365
PAT #VAL366 #VAL366
PAT #VAL367 #VAL367

PAT #VAL370 #VAL370
PAT #VAL371 #VAL371
PAT #VAL372 #VAL372
PAT #VAL373 #VAL373
PAT #VAL374 #VAL374
PAT #VAL375 #VAL375
PAT #VAL376 #VAL376
PAT #VAL377 #VAL377

PAT #VAL380 #VAL380
PAT #VAL381 #VAL381
PAT #VAL382 #VAL382
PAT #VAL383 #VAL383
PAT #VAL384 #VAL384
PAT #VAL385 #VAL385
PAT #VAL386 #VAL386
PAT #VAL387 #VAL387
                   
PAT #VAL390 #VAL390
PAT #VAL391 #VAL391
PAT #VAL392 #VAL392
PAT #VAL393 #VAL393
PAT #VAL394 #VAL394
PAT #VAL395 #VAL395
PAT #VAL396 #VAL396
PAT #VAL397 #VAL397
                   
PAT #VAL3A0 #VAL3A0
PAT #VAL3A1 #VAL3A1
PAT #VAL3A2 #VAL3A2
PAT #VAL3A3 #VAL3A3
PAT #VAL3A4 #VAL3A4
PAT #VAL3A5 #VAL3A5
PAT #VAL3A6 #VAL3A6
PAT #VAL3A7 #VAL3A7
                   
PAT #VAL3B0 #VAL3B0
PAT #VAL3B1 #VAL3B1
PAT #VAL3B2 #VAL3B2
PAT #VAL3B3 #VAL3B3
PAT #VAL3B4 #VAL3B4
PAT #VAL3B5 #VAL3B5
PAT #VAL3B6 #VAL3B6
PAT #VAL3B7 #VAL3B7
                   
PAT #VAL3C0 #VAL3C0
PAT #VAL3C1 #VAL3C1
PAT #VAL3C2 #VAL3C2
PAT #VAL3C3 #VAL3C3
PAT #VAL3C4 #VAL3C4
PAT #VAL3C5 #VAL3C5
PAT #VAL3C6 #VAL3C6
PAT #VAL3C7 #VAL3C7
                   
PAT #VAL3D0 #VAL3D0
PAT #VAL3D1 #VAL3D1
PAT #VAL3D2 #VAL3D2
PAT #VAL3D3 #VAL3D3
PAT #VAL3D4 #VAL3D4
PAT #VAL3D5 #VAL3D5
PAT #VAL3D6 #VAL3D6
PAT #VAL3D7 #VAL3D7
                   
PAT #VAL3E0 #VAL3E0
PAT #VAL3E1 #VAL3E1
PAT #VAL3E2 #VAL3E2
PAT #VAL3E3 #VAL3E3
PAT #VAL3E4 #VAL3E4
PAT #VAL3E5 #VAL3E5
PAT #VAL3E6 #VAL3E6
PAT #VAL3E7 #VAL3E7

PAT #VAL3F0 #VAL3F0
PAT #VAL3F1 #VAL3F1
PAT #VAL3F2 #VAL3F2
PAT #VAL3F3 #VAL3F3
PAT #VAL3F4 #VAL3F4
PAT #VAL3F5 #VAL3F5
PAT #VAL3F6 #VAL3F6
PAT #VAL3F7 #VAL3F7

*************************************
* PROGRAM CODE SEGMENT STARTS HERE **
*************************************
** EXECUTIVE ROUTINE LOOP
#INIT   LMR #WRITE32
#EXEC   JCB #GOBABY #START          * IF START EXPOSURE FLAG SET
        JMP #EXEC                   * ELSE JUMP BACK TO EXEC

#GOBABY LPP #KILL_EXPFLG            * KILL THE START EXP FLAG PATTERN = 0x00000001
        LMR #WRITE32                * SET 32 BIT WRITE MODE
        LSR #MCB                    * WRITE TO THE EFR
        DMS #PAN_DLY                * GIVE THE PAN SOME SLACK
        JCB #TST_1  #VCTR_1         * DO 500 KPix READOUT WITH DC CLAMP + RESET ON
        JCB #TST_2  #VCTR_2         * DO 500 KPix READOUT WITH DC CLAMP ON
        JCB #TST_4  #VCTR_3         * DO 500 KPix READOUT 
        JCB #TST_8  #VCTR_4         * DO 800 KPix READOUT 
        JCB #TST_16 #VCTR_5         * DO BIAS RAMP TEST
        JCB #TST_32 #VCTR_6         * DO FRONT END TESTS VIA DOP
        JMP #EXEC                   * NO FLAGS SET, GO HOME.

#TST_1  LPP #CDSCMD0
        CAL #RUNCDS
        JCB #TST_1 #CONT_RUN
        JMP #EXEC

#TST_2  LPP #CDSCMD1
        CAL #RUNCDS
        JCB #TST_2 #CONT_RUN
        JMP #EXEC

#TST_4  LPP #CDSCMD2
        CAL #RUNCDS
        JCB #TST_4 #CONT_RUN
        JMP #EXEC

#TST_8  LPP #CDSCMD3
        CAL #RUNCDS
        JCB #TST_8 #CONT_RUN
        JMP #EXEC

#TST_16 LPP #VAL000
        LRB #SPAN
        LRB #DACS
        LMR #WRITE16                * SET THE CORRECT MODE
        LSR #CCDACQ                 * WRITE TO THE OFFSET DACS ON CCD ACQ BOARD
        DUS 200                     * DELAY FOR SERIAL CONFIG TO END
        IPP                         * POINT TO NEXT VALUE
        LPE
        DMS 200                     * WAIT FOR OUTPUT TO SETTLE
        DMS 200                     * WAIT FOR OUTPUT TO SETTLE
        DMS 100                     * WAIT FOR OUTPUT TO SETTLE
        CAL #BIASRD
        LPE                         * END OF SPAN LOOP
        JCB #TST_16 #CONT_RUN
        JMP #EXEC

#TST_32 LMR #WRITE32
        LRB #ROWS
        LRB #COLS
        LPP #DOPHI
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT HI VOLTAGE 
        LPP #CDSCMD2            
        LDA #SEQCMD
        LSR #CCDACQ                 * FIRE OFF THE CDS MICRO SEQUENCER
        LRB #DOP_DLY
        NOP
        LPE                         * END OF DOP WAIT DELAY 
        LPP #DOPLO
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT LO AS SURROGATE CCD OUTPUT STEP 
        LRB #CDS_DLY
        NOP
        LPE
        LPE
        LPE
        RET

** READOUT ROUTINES
#BIASRD LPP #CDSCMD0
#RUNCDS LMR #WRITE32
        LDA #SEQCMD
        LRB #ROWS
        LRB #COLS            
        LSR #CCDACQ
        LRB #CDS_DLY
        NOP
        LPE
        LPE
        LPE
        RET

* END OF PROGRAM SEGMENT
