# CCD Board Testing Station Setup Mode File
#
# TEST SEQUENCE
# _7ii_
#
# HISTORY
# Version 1 - Peter Moore - 22 AUG 2005 - Adapted from _ccdlabSTIS system    
# Version 2 - Peter Moore - 28 SEP 2005 - Made to work with 8 outputs on fast machine
# Version 3 - Peter Moore - 24 APR 2006 - Made test image sizes smaller, set telemetry mode to 12 (bipolar)
# Version 4 - Peter Moore - 12 MAY 2006 - Slowed down initial acquisition to 250KPix/chan/sec
#
# DESCRIPTION
# Tests the basic ADC function, offset noise values, all CDS switches held static
# Results should show a rms noise level below 3 ADU.
#
# This setup should always be loaded first since it sets up the basic operating 
# configuration for all additional tests.
#
# Attribute Name  = Value   #Comments
## Preamble - Kill the sequencer run flag if set
mcbseqEnable=0
#
## Bring the Boards online with the system clocks
mcbBkplnSlct=0   # for a 6 slot backplane
acqClkEnbl=1     # Enable acquistion board System clock
#
## Reset the boards to condition them
resetCcd=1       # Reset the CCD acquisition board
#
## Setup some software defaults
arrayID=ccdBoardTests
arrayType=DUMMY
filename=BrdTst   # Set an appropriate file name 
imageFile=BrdTst  # Twice .. since the mec seems to like it !!
mosaicRows=8
mosaicCols=1
xPreScan=0       # Just need to read out a raw 2K x 2K image
xPostScan=0      # So set up for one array per video channel
yPostScan=0      # and 8 arrays mosaiced in X direction
colBin=1         #
rowBin=1         #
numOutputs=1     # 
outputCfg=0      #  
pxlRows=512
pxlCols=512
imageRows=512
imageCols=512
xStart[]=1
yStart[]=1
finDataType=32   # DHS_UINT four bytes 32 bits
frmsPerRdOut=1   # number of readout for one simple exposure
captureMode=1    # capture mode 0=NORMAL, 1=SEP, 2=BLOCKREAD
expMode=0        # mode of the exposure
processMode=1    # Processing mode -- Switch off the telemetry collection
expVector=1      # 1 = DO NORMAL READOUT WITH DC CLAMP + RESET ON  
                 # 2 = DO NORMAL READOUT WITH DC CLAMP ON         
                 # 4 = DO NORMAL READOUT                         
                 # 8 = DO FAST READOUT                         
                 #16 = DO BIAS RAMP TEST                           
                 #32 = DO FRONT END TESTS VIA DOP                  
asyncVector=0    # Currently not used.
rawPxlSize=4     # number of Bytes in a raw pixel value
finPxlSize=4     # number of Bytes in a finished pixel value
avNameSIze=32    # Max character length of attribute name
avValueSize=32   # Max character length of attribute value
avCommentSize=64 # Max character length of attribute comment
#
## Sequencer attributes
Rows=512          # Number of row data points
Cols=512          # Number of column data points
Span=16           # Number of steps in ramp
Dacs=8            # Number of channels that are ramped
CdsDly=39         # Delay between CTC pulses (in sequencer clocks) value of 39 gives 250Kpix/chan/sec
DopDly=8          # Delay between CTC start and DOP going low (in sequencer clocks)
#
mpuSeqClkDiv=0
contRun=0
#
## Telemetry mode setup
CCD_HVBIASTELMODE[]=12   # Internal Clock Mode, +/-10V full scale
#
## Bias voltages setup
CCD_HVBIASES[]=685      # Set all HV biases to nominal 5v 
#
## Offset voltages setup
CCD_VOFFSETS[]=1024    # Set all ADC offsets safe
#
## Video channels setup (Low Gain + WARP)
CCD_ADCCFG[]=2
#
## Initialize some of the ports
CdsReg=0x136      # Kill all CDS activity
DopReg=0          # Write zeros to DOP port
#
## Acquisition Board setup ##
Redirect[0]=0
Redirect[1]=1     # check out channel 3 at the present time
Redirect[2]=2
Redirect[3]=3
Redirect[4]=4
Redirect[5]=5
Redirect[6]=6
Redirect[7]=7
Redirect[8]=0
Redirect[9]=0
Redirect[10]=0
Redirect[11]=0
Redirect[12]=0
Redirect[13]=0
Redirect[14]=0
XfrCount=8     # Eight pixels to xfer for each CTC
DataWidth=3    # Select 18 bit data mode
PipePriority=0 # Only one acquisition board so highest priority
PipeEnbl=1     # Enable pipeline data writes
#
## Setup the voltages and enable to array
HVBiasEnbl=1
CdsEnbl=1           # Enable the CDS function
CpldLedEnable=1     # Switch off the CPLD LEDs
#
## Diagnostics ...
resetCcd=1          # for temporary bug in the busy signal ...
mcbMpuSeqBusReq=1   # Led on mcb for sequencer bus req
ccdBrdSel=0         # Ditto for CCD board
ccdCdsLoad=1        # light the sky when cds load strobe present
labSystem=1         # Kill long star date file names
