******************************************************
** PROJECT     : CCD BOARD TEST SEQUENCER CODE VERSION 0.0
** TITLE       : CCD BOARD EXERCISE CODE FOR REV 'A' HARDWARE
**             : 
**
** HISTORY     : 31/AUG/2005: PCM VER 0.0 USING NEW CCD MICRO SEQUENCER
**
** DESCRIPTION : CODE TO RUN THE CCD TEST STAND
**             : COMPILE WITH ASM4 OR LATER.
** SIGNAL
** ASSIGNMENTS : NONE USED SINCE WE RUN THIS CODE WITH ONLY THE CCD BOARD INSTALLED
**     
**********************
** TIMING CONSTANTS **
**********************
DEF #PAN_DLY        200                 * 500 ms DELAY BEFORE SENDING DATA TO PAN
DEF #CDSCMD0    x0010B00            * Run 500 KPix/sec normal acquisition
DEF #CDSCMD1    x0010B10            * Run 500 KPix/sec acquisition with DC Clamp on
DEF #CDSCMD2    x0010B20            * Run 500 KPix/sec acquisition with DC Clamp + reset on
DEF #CDSCMD3    x0010B30            * Run 800 KPix/sec acquisition
************************************************************************************
** COPY OF CCDACQ BOARD MICRO SEQUENCER CODE BLOCK
** THIS MUST BE INSERTED BY HAND AT THE END OF THE CCDBOARDTESTS_SEQUENCER.UCD FILE
************************************************************************************
*  #
*  addr=ccdSeqPatMem        # pattern memory address of CCD board
*  # Start Addr = 00 Runlength = 0B - 500 KPix/sec readout with DC clamp + reset on
*  0x047E 0x043E 0x043E 0x183E 0x043E 0x043E 0x043E 0x183E
*  0x043E 0x023F 0x013E 0x0000 0x0000 0x0000 0x0000 0x0000
*  #
*  # Start Addr = 10 Runlength = 0B - 500 KPix/sec readout with DC clamp on
*  0x0476 0x0432 0x0412 0x181A 0x0412 0x0416 0x0414 0x181C
*  0x0414 0x0215 0x0136 0x0000 0x0000 0x0000 0x0000 0x0000
*  #
*  # Start Addr = 20 Runlength = 0B - 500 KPix/sec readout
*  0x0476 0x0422 0x0402 0x180A 0x0402 0x0406 0x0404 0x180C
*  0x0404 0x0205 0x0136 0x0000 0x0000 0x0000 0x0000 0x0000
*  #
*  # Start Addr = 30 Runlength = 0B - Normal high speed acquisition = 800KPix/sec
*  0x0176 0x0122 0x0202 0x100a 0x0102 0x0106 0x0104 0x100c
*  0x0204 0x0105 0x0136 0x0000 0x0000 0x0000 0x0000 0x0000 
*  #
*  
*  
*  
*  
***********************************************************************************
*
*******************************
** LOOP REGISTER DEFINITIONS **
*******************************
DEF #ROWS         0                 * NUMBER OF ROWS TO READOUT - NOMINALLY SET TO 1
DEF #COLS         1                 * NUMBER OF COLUMNS TO READOUT  - NOMINALLY SET TO 2048
DEF #SPAN         2                 * NUMBER OF TIMES TO SET DACS - NOMINALLY SET TO 32
DEF #DACS         3                 * NUMBER OF DACS TO SET THROUGH EACH SPAN STEP - NOMINALLY SET TO 8
DEF #CDS_DLY      4                 * Delay time between CDS sequence triggers  - NOMINALLY SET TO 5 us
DEF #DOP_DLY      5                 * DELAY BETWEEN FIRING CDS AND SETTING THE DOP NEG STEP 
**
**************************************************************
** JUMP FLAG DEFINITIONS - BIT POSITION IN COMMAND REGISTER **
**************************************************************
DEF #SYNC        1                  * Jump on sync bit high
DEF #ITC         2                  * Jump on Integration time expired
DEF #START       3                  * Jump on start exposure flag set
DEF #VCTR_1      4                  * STRVCTR =  1: READOUT CLAMPED AND RESET MODE
DEF #VCTR_2      5                  * STRVCTR =  2: READOUT CLAMPED MODE
DEF #VCTR_3      6                  * STRVCTR =  4: READOUT NORMALLY
DEF #VCTR_4      7                  * STRVCTR =  8:
DEF #VCTR_5      8                  * STRVCTR = 16: 
DEF #VCTR_6      9                  * STRVCTR = 32: 
DEF #VCTR_7     10                  * STRVCTR = 64:
DEF #VCTR_8     11                  * STRVCTR =128:
DEF #CONT_RUN   12                  * USER BIT 1: LOOP INDEFINATELY ON TESTS
DEF #USR_2      13                  * Jump on user mode bit value 2
DEF #USR_3      14                  * Jump on user mode bit value 4
DEF #USR_4      15                  * Jump on user mode bit value 8
**
****************************
** EFR REGISTER CONSTANTS **
****************************
DEF #KILL_EXPFLG    x00000001       * Cancel start exposure flag (bit 3 of Command Register) using the EFR register
DEF #STRT_INTCNTR   x00000002       * Start the integration time counter using the EFR register
DEF #STOP_INTCNTR   x00000004       * Stop the integration time counter using the EFR register
DEF #LSR_AUTO_KILL  x00000100       * Enables automatic board select cancel after an LSR instruction
DEF #LSR_MAN_RESET  x00000200       * Disables automatic board select cancel. LSR will remain active until an LSR #DSLCT is issued
DEF #SET_SYNC_LOW   x00004000       * If enabled as master DHE, set sync bit low after sync delay
DEF #SET_SYNC_HIGH  x00008000       * If enabled as master DHE, set sync signal high immediately
DEF #KILLANDSYNC    x00004001
DEF #PWR_SYNC       x00002000       * sync pulse for power supply sync function

**
*****************************
** MODE REGISTER CONSTANTS **
*****************************
DEF #RESET       0                  * Mode register constant for board reset operation
DEF #READ        1                  * Mode register constant for read operation
DEF #WRITE16     2                  * Mode register constant for 16 bit write operation
DEF #WRITE32     3                  * Mode register constant for 32 bit write operation
**
**********************************
** LSR BOARD SELECT ASSIGNMENTS **
**********************************
DEF #DSLCT       0
DEF #MCB         1
DEF #CCDACQ     32                  * ASSIGNED TO SLOT 6
**
** CCDACQ BOARD ADDRESS POINTERS
DEF #CDSREG      x0000
DEF #DOPREG      x0001
DEF #BRSTCMD     x0004
DEF #SEQCMD      x0005
DEF #XFERCNT     x030F0000          * To enable/disable data xfers for warm up
DEF #XFERON      #XFERCNT OR 8
DEF #XFEROFF     #XFERCNT
**
********************************
** DOP PORT VALUES FOR EDGE TEST
********************************
DEF #DOPHI     x00000003
DEF #DOPLO     x00000002
**
**********************
** DAC OFFSET WORDS **
**********************
** ADDRESS BASES
DEF #DAC0_ADDR x02100000
DEF #DAC1_ADDR x02110000
DEF #DAC2_ADDR x02120000
DEF #DAC3_ADDR x02130000
DEF #DAC4_ADDR x02140000
DEF #DAC5_ADDR x02150000
DEF #DAC6_ADDR x02160000
DEF #DAC7_ADDR x02170000
**
** DATA VALUES
DEF #OFFSET00 x0000
DEF #OFFSET04 x0100
DEF #OFFSET08 x0200
DEF #OFFSET0C x0300
DEF #OFFSET10 x0400
DEF #OFFSET14 x0500
DEF #OFFSET18 x0600
DEF #OFFSET1C x0700
DEF #OFFSET20 x0800
DEF #OFFSET24 x0900
DEF #OFFSET28 x0A00
DEF #OFFSET2C x0B00
DEF #OFFSET30 x0C00
DEF #OFFSET34 x0D00
DEF #OFFSET38 x0E00
DEF #OFFSET3C x0F00

DEF #VAL000 #DAC0_ADDR OR #OFFSET00
DEF #VAL001 #DAC1_ADDR OR #OFFSET00
DEF #VAL002 #DAC2_ADDR OR #OFFSET00
DEF #VAL003 #DAC3_ADDR OR #OFFSET00
DEF #VAL004 #DAC4_ADDR OR #OFFSET00
DEF #VAL005 #DAC5_ADDR OR #OFFSET00
DEF #VAL006 #DAC6_ADDR OR #OFFSET00
DEF #VAL007 #DAC7_ADDR OR #OFFSET00

DEF #VAL040 #DAC0_ADDR OR #OFFSET04
DEF #VAL041 #DAC1_ADDR OR #OFFSET04
DEF #VAL042 #DAC2_ADDR OR #OFFSET04
DEF #VAL043 #DAC3_ADDR OR #OFFSET04
DEF #VAL044 #DAC4_ADDR OR #OFFSET04
DEF #VAL045 #DAC5_ADDR OR #OFFSET04
DEF #VAL046 #DAC6_ADDR OR #OFFSET04
DEF #VAL047 #DAC7_ADDR OR #OFFSET04

DEF #VAL080 #DAC0_ADDR OR #OFFSET08
DEF #VAL081 #DAC1_ADDR OR #OFFSET08
DEF #VAL082 #DAC2_ADDR OR #OFFSET08
DEF #VAL083 #DAC3_ADDR OR #OFFSET08
DEF #VAL084 #DAC4_ADDR OR #OFFSET08
DEF #VAL085 #DAC5_ADDR OR #OFFSET08
DEF #VAL086 #DAC6_ADDR OR #OFFSET08
DEF #VAL087 #DAC7_ADDR OR #OFFSET08

DEF #VAL0C0 #DAC0_ADDR OR #OFFSET0C
DEF #VAL0C1 #DAC1_ADDR OR #OFFSET0C
DEF #VAL0C2 #DAC2_ADDR OR #OFFSET0C
DEF #VAL0C3 #DAC3_ADDR OR #OFFSET0C
DEF #VAL0C4 #DAC4_ADDR OR #OFFSET0C
DEF #VAL0C5 #DAC5_ADDR OR #OFFSET0C
DEF #VAL0C6 #DAC6_ADDR OR #OFFSET0C
DEF #VAL0C7 #DAC7_ADDR OR #OFFSET0C

DEF #VAL100 #DAC0_ADDR OR #OFFSET10
DEF #VAL101 #DAC1_ADDR OR #OFFSET10
DEF #VAL102 #DAC2_ADDR OR #OFFSET10
DEF #VAL103 #DAC3_ADDR OR #OFFSET10
DEF #VAL104 #DAC4_ADDR OR #OFFSET10
DEF #VAL105 #DAC5_ADDR OR #OFFSET10
DEF #VAL106 #DAC6_ADDR OR #OFFSET10
DEF #VAL107 #DAC7_ADDR OR #OFFSET10

DEF #VAL140 #DAC0_ADDR OR #OFFSET14
DEF #VAL141 #DAC1_ADDR OR #OFFSET14
DEF #VAL142 #DAC2_ADDR OR #OFFSET14
DEF #VAL143 #DAC3_ADDR OR #OFFSET14
DEF #VAL144 #DAC4_ADDR OR #OFFSET14
DEF #VAL145 #DAC5_ADDR OR #OFFSET14
DEF #VAL146 #DAC6_ADDR OR #OFFSET14
DEF #VAL147 #DAC7_ADDR OR #OFFSET14

DEF #VAL180 #DAC0_ADDR OR #OFFSET18
DEF #VAL181 #DAC1_ADDR OR #OFFSET18
DEF #VAL182 #DAC2_ADDR OR #OFFSET18
DEF #VAL183 #DAC3_ADDR OR #OFFSET18
DEF #VAL184 #DAC4_ADDR OR #OFFSET18
DEF #VAL185 #DAC5_ADDR OR #OFFSET18
DEF #VAL186 #DAC6_ADDR OR #OFFSET18
DEF #VAL187 #DAC7_ADDR OR #OFFSET18

DEF #VAL1C0 #DAC0_ADDR OR #OFFSET1C
DEF #VAL1C1 #DAC1_ADDR OR #OFFSET1C
DEF #VAL1C2 #DAC2_ADDR OR #OFFSET1C
DEF #VAL1C3 #DAC3_ADDR OR #OFFSET1C
DEF #VAL1C4 #DAC4_ADDR OR #OFFSET1C
DEF #VAL1C5 #DAC5_ADDR OR #OFFSET1C
DEF #VAL1C6 #DAC6_ADDR OR #OFFSET1C
DEF #VAL1C7 #DAC7_ADDR OR #OFFSET1C
DEF #VAL200 #DAC0_ADDR OR #OFFSET20
DEF #VAL201 #DAC1_ADDR OR #OFFSET20
DEF #VAL202 #DAC2_ADDR OR #OFFSET20
DEF #VAL203 #DAC3_ADDR OR #OFFSET20
DEF #VAL204 #DAC4_ADDR OR #OFFSET20
DEF #VAL205 #DAC5_ADDR OR #OFFSET20
DEF #VAL206 #DAC6_ADDR OR #OFFSET20
DEF #VAL207 #DAC7_ADDR OR #OFFSET20

DEF #VAL240 #DAC0_ADDR OR #OFFSET24
DEF #VAL241 #DAC1_ADDR OR #OFFSET24
DEF #VAL242 #DAC2_ADDR OR #OFFSET24
DEF #VAL243 #DAC3_ADDR OR #OFFSET24
DEF #VAL244 #DAC4_ADDR OR #OFFSET24
DEF #VAL245 #DAC5_ADDR OR #OFFSET24
DEF #VAL246 #DAC6_ADDR OR #OFFSET24
DEF #VAL247 #DAC7_ADDR OR #OFFSET24

DEF #VAL280 #DAC0_ADDR OR #OFFSET28
DEF #VAL281 #DAC1_ADDR OR #OFFSET28
DEF #VAL282 #DAC2_ADDR OR #OFFSET28
DEF #VAL283 #DAC3_ADDR OR #OFFSET28
DEF #VAL284 #DAC4_ADDR OR #OFFSET28
DEF #VAL285 #DAC5_ADDR OR #OFFSET28
DEF #VAL286 #DAC6_ADDR OR #OFFSET28
DEF #VAL287 #DAC7_ADDR OR #OFFSET28

DEF #VAL2C0 #DAC0_ADDR OR #OFFSET2C
DEF #VAL2C1 #DAC1_ADDR OR #OFFSET2C
DEF #VAL2C2 #DAC2_ADDR OR #OFFSET2C
DEF #VAL2C3 #DAC3_ADDR OR #OFFSET2C
DEF #VAL2C4 #DAC4_ADDR OR #OFFSET2C
DEF #VAL2C5 #DAC5_ADDR OR #OFFSET2C
DEF #VAL2C6 #DAC6_ADDR OR #OFFSET2C
DEF #VAL2C7 #DAC7_ADDR OR #OFFSET2C

DEF #VAL300 #DAC0_ADDR OR #OFFSET30
DEF #VAL301 #DAC1_ADDR OR #OFFSET30
DEF #VAL302 #DAC2_ADDR OR #OFFSET30
DEF #VAL303 #DAC3_ADDR OR #OFFSET30
DEF #VAL304 #DAC4_ADDR OR #OFFSET30
DEF #VAL305 #DAC5_ADDR OR #OFFSET30
DEF #VAL306 #DAC6_ADDR OR #OFFSET30
DEF #VAL307 #DAC7_ADDR OR #OFFSET30

DEF #VAL340 #DAC0_ADDR OR #OFFSET34
DEF #VAL341 #DAC1_ADDR OR #OFFSET34
DEF #VAL342 #DAC2_ADDR OR #OFFSET34
DEF #VAL343 #DAC3_ADDR OR #OFFSET34
DEF #VAL344 #DAC4_ADDR OR #OFFSET34
DEF #VAL345 #DAC5_ADDR OR #OFFSET34
DEF #VAL346 #DAC6_ADDR OR #OFFSET34
DEF #VAL347 #DAC7_ADDR OR #OFFSET34

DEF #VAL380 #DAC0_ADDR OR #OFFSET38
DEF #VAL381 #DAC1_ADDR OR #OFFSET38
DEF #VAL382 #DAC2_ADDR OR #OFFSET38
DEF #VAL383 #DAC3_ADDR OR #OFFSET38
DEF #VAL384 #DAC4_ADDR OR #OFFSET38
DEF #VAL385 #DAC5_ADDR OR #OFFSET38
DEF #VAL386 #DAC6_ADDR OR #OFFSET38
DEF #VAL387 #DAC7_ADDR OR #OFFSET38

DEF #VAL3C0 #DAC0_ADDR OR #OFFSET3C
DEF #VAL3C1 #DAC1_ADDR OR #OFFSET3C
DEF #VAL3C2 #DAC2_ADDR OR #OFFSET3C
DEF #VAL3C3 #DAC3_ADDR OR #OFFSET3C
DEF #VAL3C4 #DAC4_ADDR OR #OFFSET3C
DEF #VAL3C5 #DAC5_ADDR OR #OFFSET3C
DEF #VAL3C6 #DAC6_ADDR OR #OFFSET3C
DEF #VAL3C7 #DAC7_ADDR OR #OFFSET3C

********************************
** PATTERN MEMORY DEFINITIONS **
********************************
** PATTERN MEMORY SEGMENTATION MAP
DEF #PATSEG_00      x0000           * Pattern memory origin - Initialization stuff
DEF #PATSEG_10      x0010
DEF #PATSEG_20      x0020

ORG PAT #PATSEG_00                    * ********* GENERAL CONSTANTS KEPT IN PAT MEM ********* 
PAT #KILL_EXPFLG    #KILL_EXPFLG      * We can use the same label name here because they are in different contexts
PAT #STRT_INTCNTR   #STRT_INTCNTR     * The definition earlier points to a data value. The label here points to
PAT #STOP_INTCNTR   #STOP_INTCNTR     * a pattern memory address
PAT #PWR_SYNC       #PWR_SYNC
PAT #CDSCMD0        #CDSCMD0
PAT #CDSCMD1        #CDSCMD1
PAT #CDSCMD2        #CDSCMD2
PAT #CDSCMD3        #CDSCMD3

ORG PAT #PATSEG_10
PAT #DOPLO  #DOPLO
PAT #DOPHI  #DOPHI
PAT #XFERON  #XFERON
PAT #XFEROFF #XFEROFF

ORG PAT #PATSEG_20                    * BEGINNING OF OFFSET DAC DATA
PAT #VAL000 #VAL000
PAT #VAL001 #VAL001
PAT #VAL002 #VAL002
PAT #VAL003 #VAL003
PAT #VAL004 #VAL004
PAT #VAL005 #VAL005
PAT #VAL006 #VAL006
PAT #VAL007 #VAL007
                   
PAT #VAL040 #VAL040
PAT #VAL041 #VAL041
PAT #VAL042 #VAL042
PAT #VAL043 #VAL043
PAT #VAL044 #VAL044
PAT #VAL045 #VAL045
PAT #VAL046 #VAL046
PAT #VAL047 #VAL047

PAT #VAL080 #VAL080
PAT #VAL081 #VAL081
PAT #VAL082 #VAL082
PAT #VAL083 #VAL083
PAT #VAL084 #VAL084
PAT #VAL085 #VAL085
PAT #VAL086 #VAL086
PAT #VAL087 #VAL087
                   
PAT #VAL0C0 #VAL0C0
PAT #VAL0C1 #VAL0C1
PAT #VAL0C2 #VAL0C2
PAT #VAL0C3 #VAL0C3
PAT #VAL0C4 #VAL0C4
PAT #VAL0C5 #VAL0C5
PAT #VAL0C6 #VAL0C6
PAT #VAL0C7 #VAL0C7

PAT #VAL100 #VAL100
PAT #VAL101 #VAL101
PAT #VAL102 #VAL102
PAT #VAL103 #VAL103
PAT #VAL104 #VAL104
PAT #VAL105 #VAL105
PAT #VAL106 #VAL106
PAT #VAL107 #VAL107
                   
PAT #VAL140 #VAL140
PAT #VAL141 #VAL141
PAT #VAL142 #VAL142
PAT #VAL143 #VAL143
PAT #VAL144 #VAL144
PAT #VAL145 #VAL145
PAT #VAL146 #VAL146
PAT #VAL147 #VAL147

PAT #VAL180 #VAL180
PAT #VAL181 #VAL181
PAT #VAL182 #VAL182
PAT #VAL183 #VAL183
PAT #VAL184 #VAL184
PAT #VAL185 #VAL185
PAT #VAL186 #VAL186
PAT #VAL187 #VAL187
                   
PAT #VAL1C0 #VAL1C0
PAT #VAL1C1 #VAL1C1
PAT #VAL1C2 #VAL1C2
PAT #VAL1C3 #VAL1C3
PAT #VAL1C4 #VAL1C4
PAT #VAL1C5 #VAL1C5
PAT #VAL1C6 #VAL1C6
PAT #VAL1C7 #VAL1C7

PAT #VAL200 #VAL200
PAT #VAL201 #VAL201
PAT #VAL202 #VAL202
PAT #VAL203 #VAL203
PAT #VAL204 #VAL204
PAT #VAL205 #VAL205

PAT #VAL206 #VAL206
PAT #VAL207 #VAL207                   
PAT #VAL240 #VAL240
PAT #VAL241 #VAL241
PAT #VAL242 #VAL242
PAT #VAL243 #VAL243
PAT #VAL244 #VAL244
PAT #VAL245 #VAL245
PAT #VAL246 #VAL246
PAT #VAL247 #VAL247

PAT #VAL280 #VAL280
PAT #VAL281 #VAL281
PAT #VAL282 #VAL282
PAT #VAL283 #VAL283
PAT #VAL284 #VAL284
PAT #VAL285 #VAL285
PAT #VAL286 #VAL286
PAT #VAL287 #VAL287
                   
PAT #VAL2C0 #VAL2C0
PAT #VAL2C1 #VAL2C1
PAT #VAL2C2 #VAL2C2
PAT #VAL2C3 #VAL2C3
PAT #VAL2C4 #VAL2C4
PAT #VAL2C5 #VAL2C5
PAT #VAL2C6 #VAL2C6
PAT #VAL2C7 #VAL2C7

PAT #VAL300 #VAL300
PAT #VAL301 #VAL301
PAT #VAL302 #VAL302
PAT #VAL303 #VAL303
PAT #VAL304 #VAL304
PAT #VAL305 #VAL305
PAT #VAL306 #VAL306
PAT #VAL307 #VAL307
                   
PAT #VAL340 #VAL340
PAT #VAL341 #VAL341
PAT #VAL342 #VAL342
PAT #VAL343 #VAL343
PAT #VAL344 #VAL344
PAT #VAL345 #VAL345
PAT #VAL346 #VAL346
PAT #VAL347 #VAL347

PAT #VAL380 #VAL380
PAT #VAL381 #VAL381
PAT #VAL382 #VAL382
PAT #VAL383 #VAL383
PAT #VAL384 #VAL384
PAT #VAL385 #VAL385
PAT #VAL386 #VAL386
PAT #VAL387 #VAL387
                   
PAT #VAL3C0 #VAL3C0
PAT #VAL3C1 #VAL3C1
PAT #VAL3C2 #VAL3C2
PAT #VAL3C3 #VAL3C3
PAT #VAL3C4 #VAL3C4
PAT #VAL3C5 #VAL3C5
PAT #VAL3C6 #VAL3C6
PAT #VAL3C7 #VAL3C7

PAT #DOPTST1 3
PAT #DOPTST2 2

*************************************
* PROGRAM CODE SEGMENT STARTS HERE **
*************************************
** EXECUTIVE ROUTINE LOOP
#INIT   LMR #WRITE32
#EXEC   JCB #GOBABY #START          * IF START EXPOSURE FLAG SET
        JMP #EXEC                   * ELSE JUMP BACK TO EXEC

#GOBABY LPP #KILL_EXPFLG            * KILL THE START EXP FLAG PATTERN = 0x00000001
        LMR #WRITE32                * SET 32 BIT WRITE MODE
        LSR #MCB                    * WRITE TO THE EFR
        DMS #PAN_DLY                * GIVE THE PAN SOME SLACK
        JCB #TST_1  #VCTR_1         * DO 500 KPix READOUT WITH DC CLAMP + RESET ON
        JCB #TST_2  #VCTR_2         * DO 500 KPix READOUT WITH DC CLAMP ON
        JCB #TST_4  #VCTR_3         * DO 500 KPix READOUT 
        JCB #TST_8  #VCTR_4         * DO 800 KPix READOUT 
        JCB #TST_16 #VCTR_5         * DO BIAS RAMP TEST
        JCB #TST_32 #VCTR_6         * DO FRONT END TESTS VIA DOP
	JCB #TST_64 #VCTR_7	    * DO DOP STIMULUS TEST - ADDED 20060512 
        JMP #EXEC                   * NO FLAGS SET, GO HOME.

#TST_1  LPP #CDSCMD0
        CAL #RUNCDS
        JCB #TST_1 #CONT_RUN
        JMP #EXEC

#TST_2  LPP #CDSCMD1
        CAL #RUNCDS
        JCB #TST_2 #CONT_RUN
        JMP #EXEC

#TST_4  LPP #CDSCMD2
        CAL #RUNCDS
        JCB #TST_4 #CONT_RUN
        JMP #EXEC

#TST_8  LPP #CDSCMD3
        CAL #RUNCDS
        JCB #TST_8 #CONT_RUN
        JMP #EXEC

#TST_16 LPP #VAL000
        LRB #SPAN
        LRB #DACS
        LMR #WRITE16                * SET THE CORRECT MODE
        LSR #CCDACQ                 * WRITE TO THE OFFSET DACS ON CCD ACQ BOARD
        DUS 200                     * DELAY FOR SERIAL CONFIG TO END
        IPP                         * POINT TO NEXT VALUE
        LPE
        DMS 200                     * WAIT FOR OUTPUT TO SETTLE
        DMS 200                     * WAIT FOR OUTPUT TO SETTLE
        DMS 100                     * WAIT FOR OUTPUT TO SETTLE
        CAL #BIASRD
        LPE                         * END OF SPAN LOOP
        JCB #TST_16 #CONT_RUN
        JMP #EXEC

#TST_32 LMR #WRITE32
        LPP #DOPLO
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT HI VOLTAGE
        DUS 4                       * ALLOW TO SETTLE 
        LRB #ROWS
        LRB #COLS
        LPP #CDSCMD2            
        LDA #SEQCMD
        LSR #CCDACQ                 * FIRE OFF THE CDS MICRO SEQUENCER
        LRB #DOP_DLY
        NOP
        LPE                         * END OF DOP WAIT DELAY 
        LPP #DOPHI
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT LO AS SURROGATE CCD OUTPUT STEP
        DUS 2                       * ALLOW THE SAMPLE TO FINISH 
        LPP #DOPLO
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT HI VOLTAGE AGAIN
        LRB #CDS_DLY
        NOP
        LPE
        LPE
        LPE
        JCB #TST_32 #CONT_RUN
        JMP #EXEC

#TST_64 LRB #ROWS
	LRB #COLS
	LPP #DOPTST1
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT LO AS SURROGATE CCD OUTPUT STEP
        DUS 5                       * ALLOW THE SAMPLE TO FINISH 
        LPP #DOPTST2
        LDA #DOPREG
        LSR #CCDACQ                 * SET DOP PORT HI VOLTAGE AGAIN
	DUS 5
	LPE
	LPE
        JCB #TST_64 #CONT_RUN
        JMP #EXEC

** READOUT ROUTINES
#BIASRD LPP #CDSCMD0
#RUNCDS CAL #WARMUP
        LMR #WRITE32
        LDA #SEQCMD
        LRB #ROWS
        LRB #COLS
	CAL #PWRSYNC            
        LSR #CCDACQ
        LRB #CDS_DLY
        NOP
        LPE
        LPE
        LPE
        RET

#WARMUP LMR #WRITE16                * In WARP mode we need to pretrigger the ADC to obtain 
        LPP #XFEROFF                * calibration.
        LSR #CCDACQ                 * Switch off the pipeline xfer
        LMR #WRITE32
        LDA #SEQCMD
        LPP #CDSCMD0
        LSR #CCDACQ                 * Trigger an ADC cycle
        DUS 4                       * and wait for it to complete
        LMR #WRITE16
        LPP #XFERON
        LSR #CCDACQ                 * Re-establish the pipeline xfers
        RET

#PWRSYNC LPP #PWR_SYNC
        LSR #MCB
        RET

* END OF PROGRAM SEGMENT 

